/*
output_map.c
defines an array of pointers to doubles that map to all the intermediate
variables in bgc

*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
Biome-BGCMuSo v5.0.
Original code: Copyright 2000, Peter E. Thornton
Numerical Terradynamic Simulation Group, The University of Montana, USA
Modified code: Copyright 2018, D. Hidy [dori.hidy@gmail.com]
Hungarian Academy of Sciences, Hungary
See the website of Biome-BGCMuSo at http://nimbus.elte.hu/bbgc/ for documentation, model executable and example input files.
*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <math.h>
#include <malloc.h>
#include "bgc_struct.h"     /* structure definitions */
#include "bgc_func.h"       /* function prototypes */
#include "bgc_constants.h"


int output_map_init(double** output_map, phenology_struct* phen, metvar_struct* metv, wstate_struct* ws,
	wflux_struct* wf, cstate_struct* cs, cflux_struct* cf, nstate_struct* ns, nflux_struct* nf, 
	epvar_struct* epv, psn_struct* psn_sun, psn_struct* psn_shade, summary_struct* summary)

/*int output_map_init(double** output_map, const phenology_struct* phen, const metvar_struct* metv, const wstate_struct* ws,
	const wflux_struct* wf, const cstate_struct* cs, const cflux_struct* cf, const nstate_struct* ns, const nflux_struct* nf,
	const epvar_struct* epv, const psn_struct* psn_sun, const psn_struct* psn_shade, const summary_struct* summary);*/
{
	int ok=1;
	int i;
	
	for (i=0 ; ok && i<NMAP ; i++)
	{
		output_map[i] = NULL;
	}
	
	if (ok)
	{
		output_map[0] = &phen->onday;
		output_map[1] = &phen->offday;
		output_map[2] = &phen->remdays_curgrowth;
		output_map[3] = &phen->remdays_transfer;
		output_map[4] = &phen->remdays_litfall;
		output_map[5] = &phen->predays_transfer;
		output_map[6] = &phen->predays_litfall;
		output_map[7] = &phen->n_growthday;
		output_map[8] = &phen->n_transferday;
		output_map[9] = &phen->n_litfallday;
		output_map[10] = &phen->yday_phen;
		output_map[11] = &phen->phpsl_dev_rate;
		output_map[12] = &phen->vern_dev_rate;
		output_map[13] = &phen->vern_days;
		output_map[14] = &phen->GDD_limit;
		output_map[15] = &phen->GDD_crit[0];
		output_map[16] = &phen->GDD_crit[1];
		output_map[17] = &phen->GDD_crit[2];
		output_map[18] = &phen->GDD_crit[3];
		output_map[19] = &phen->GDD_crit[4];
		output_map[20] = &phen->GDD_crit[5];
		output_map[21] = &phen->GDD_crit[6];
		output_map[22] = &phen->GDD_emergSTART;
		output_map[23] = &phen->GDD_emergEND;
		output_map[40] = &metv->tnight;
		output_map[41] = &metv->tavg11_ra;
		output_map[42] = &metv->tavg10_ra;
		output_map[43] = &metv->tavg30_ra;
		output_map[44] = &metv->F_temprad;
		output_map[45] = &metv->F_temprad_ra;
		output_map[46] = &metv->tsoil_surface;
		output_map[47] = &metv->tsoil_surface_pre;
		output_map[48] = &metv->tsoil_avg;
		output_map[49] = &metv->tsoil[0];
		output_map[50] = &metv->tsoil[1];
		output_map[51] = &metv->tsoil[2];
		output_map[52] = &metv->tsoil[3];
		output_map[53] = &metv->tsoil[4];
		output_map[54] = &metv->tsoil[5];
		output_map[55] = &metv->tsoil[6];
		output_map[56] = &metv->tsoil[7];
		output_map[57] = &metv->tsoil[8];
		output_map[58] = &metv->tsoil[9];
		output_map[59] = &metv->swRADnet;
		output_map[60] = &metv->lwRADnet;
		output_map[61] = &metv->RADnet;
		output_map[62] = &metv->RADnet_per_plaisun;
		output_map[63] = &metv->RADnet_per_plaishade;
		output_map[64] = &metv->swavgfd;
		output_map[65] = &metv->swabs;
		output_map[66] = &metv->swtrans;
		output_map[67] = &metv->swabs_per_plaisun;
		output_map[68] = &metv->swabs_per_plaishade;
		output_map[69] = &metv->ppfd_per_plaisun;
		output_map[70] = &metv->ppfd_per_plaishade;
		output_map[71] = &metv->parabs;
		output_map[72] = &metv->parabs_plaisun;
		output_map[73] = &metv->parabs_plaishade;
		output_map[74] = &metv->GDD;
		output_map[75] = &metv->GDD_wMOD;
		output_map[76] = &metv->GDDpre;
		output_map[77] = &metv->pa;
		output_map[80] = &ws->soilw[0];
		output_map[81] = &ws->soilw[1];
		output_map[82] = &ws->soilw[2];
		output_map[83] = &ws->soilw[3];
		output_map[84] = &ws->soilw[4];
		output_map[85] = &ws->soilw[5];
		output_map[86] = &ws->soilw[6];
		output_map[87] = &ws->soilw[7];
		output_map[88] = &ws->soilw[8];
		output_map[89] = &ws->soilw[9];
		output_map[90] = &ws->soilw_SUM;
		output_map[91] = &ws->pond_water;
		output_map[92] = &ws->snoww;
		output_map[93] = &ws->canopyw;
		output_map[94] = &ws->prcp_src;
		output_map[95] = &ws->soilevap_snk;
		output_map[96] = &ws->snowsubl_snk;
		output_map[97] = &ws->canopyevap_snk;
		output_map[98] = &ws->pondwevap_snk;
		output_map[99] = &ws->trans_snk;
		output_map[100] = &ws->runoff_snk;
		output_map[101] = &ws->deeppercolation_snk;
		output_map[102] = &ws->groundwater_src;
		output_map[103] = &ws->canopyw_THNsnk;
		output_map[104] = &ws->canopyw_MOWsnk;
		output_map[105] = &ws->canopyw_HRVsnk;
		output_map[106] = &ws->canopyw_PLGsnk;
		output_map[107] = &ws->canopyw_GRZsnk;
		output_map[108] = &ws->IRGsrc;
		output_map[109] = &ws->FRZsrc;
		output_map[110] = &ws->balanceERR;
		output_map[111] = &ws->in;
		output_map[112] = &ws->out;
		output_map[113] = &ws->store;
		output_map[150] = &wf->prcp_to_canopyw;
		output_map[151] = &wf->prcp_to_soilw;
		output_map[152] = &wf->prcp_to_snoww;
		output_map[153] = &wf->prcp_to_runoff;
		output_map[154] = &wf->canopyw_evap;
		output_map[155] = &wf->canopyw_to_soilw;
		output_map[156] = &wf->pondw_evap;
		output_map[157] = &wf->snoww_subl;
		output_map[158] = &wf->snoww_to_soilw;
		output_map[159] = &wf->soilw_evap;
		output_map[160] = &wf->soilw_trans[0];
		output_map[161] = &wf->soilw_trans[1];
		output_map[162] = &wf->soilw_trans[2];
		output_map[163] = &wf->soilw_trans[3];
		output_map[164] = &wf->soilw_trans[4];
		output_map[165] = &wf->soilw_trans[5];
		output_map[166] = &wf->soilw_trans[6];
		output_map[167] = &wf->soilw_trans[7];
		output_map[168] = &wf->soilw_trans[8];
		output_map[169] = &wf->soilw_trans[9];
		output_map[170] = &wf->soilw_trans_SUM;
		output_map[171] = &wf->evapotransp;
		output_map[172] = &wf->pondw_to_soilw;
		output_map[173] = &wf->soilw_to_pondw;
		output_map[174] = &wf->soilw_percolated[0];
		output_map[175] = &wf->soilw_percolated[1];
		output_map[176] = &wf->soilw_percolated[2];
		output_map[177] = &wf->soilw_percolated[3];
		output_map[178] = &wf->soilw_percolated[4];
		output_map[179] = &wf->soilw_percolated[5];
		output_map[180] = &wf->soilw_percolated[6];
		output_map[181] = &wf->soilw_percolated[7];
		output_map[182] = &wf->soilw_percolated[8];
		output_map[183] = &wf->soilw_percolated[9];
		output_map[184] = &wf->soilw_diffused[0];
		output_map[185] = &wf->soilw_diffused[1];
		output_map[186] = &wf->soilw_diffused[2];
		output_map[187] = &wf->soilw_diffused[3];
		output_map[188] = &wf->soilw_diffused[4];
		output_map[189] = &wf->soilw_diffused[5];
		output_map[190] = &wf->soilw_diffused[6];
		output_map[191] = &wf->soilw_diffused[7];
		output_map[192] = &wf->soilw_diffused[8];
		output_map[193] = &wf->soilw_diffused[9];
		output_map[194] = &wf->soilw_from_GW[0];
		output_map[195] = &wf->soilw_from_GW[1];
		output_map[196] = &wf->soilw_from_GW[2];
		output_map[197] = &wf->soilw_from_GW[3];
		output_map[198] = &wf->soilw_from_GW[4];
		output_map[199] = &wf->soilw_from_GW[5];
		output_map[200] = &wf->soilw_from_GW[6];
		output_map[201] = &wf->soilw_from_GW[7];
		output_map[202] = &wf->soilw_from_GW[8];
		output_map[203] = &wf->soilw_from_GW[9];
		output_map[204] = &wf->soilw_rootzone_leach;
		output_map[205] = &wf->canopyw_to_THN;
		output_map[206] = &wf->canopyw_to_MOW;
		output_map[207] = &wf->canopyw_to_HRV;
		output_map[208] = &wf->canopyw_to_PLG;
		output_map[209] = &wf->canopyw_to_GRZ;
		output_map[210] = &wf->IRG_to_prcp;
		output_map[211] = &wf->FRZ_to_soilw;
		output_map[212] = &wf->pot_evap;
		output_map[300] = &cs->leafcSUM_phenphase[0];
		output_map[301] = &cs->leafcSUM_phenphase[1];
		output_map[302] = &cs->leafcSUM_phenphase[2];
		output_map[303] = &cs->leafcSUM_phenphase[3];
		output_map[304] = &cs->leafcSUM_phenphase[4];
		output_map[305] = &cs->leafcSUM_phenphase[5];
		output_map[306] = &cs->leafcSUM_phenphase[6];
		output_map[307] = &cs->leafc;
		output_map[308] = &cs->leafc_storage;
		output_map[309] = &cs->leafc_transfer;
		output_map[310] = &cs->frootc;
		output_map[311] = &cs->frootc_storage;
		output_map[312] = &cs->frootc_transfer;
		output_map[313] = &cs->fruitc;
		output_map[314] = &cs->fruitc_storage;
		output_map[315] = &cs->fruitc_transfer;
		output_map[316] = &cs->softstemc;
		output_map[317] = &cs->softstemc_storage;
		output_map[318] = &cs->softstemc_transfer;
		output_map[319] = &cs->livestemc;
		output_map[320] = &cs->livestemc_storage;
		output_map[321] = &cs->livestemc_transfer;
		output_map[322] = &cs->deadstemc;
		output_map[323] = &cs->deadstemc_storage;
		output_map[324] = &cs->deadstemc_transfer;
		output_map[325] = &cs->livecrootc;
		output_map[326] = &cs->livecrootc_storage;
		output_map[327] = &cs->livecrootc_transfer;
		output_map[328] = &cs->deadcrootc;
		output_map[329] = &cs->deadcrootc_storage;
		output_map[330] = &cs->deadcrootc_transfer;
		output_map[331] = &cs->gresp_storage;
		output_map[332] = &cs->gresp_transfer;
		output_map[333] = &cs->nsc_w;
		output_map[334] = &cs->nsc_nw;
		output_map[335] = &cs->sc_w;
		output_map[336] = &cs->sc_nw;
		output_map[337] = &cs->cwdc[0];
		output_map[338] = &cs->cwdc[1];
		output_map[339] = &cs->cwdc[2];
		output_map[340] = &cs->cwdc[3];
		output_map[341] = &cs->cwdc[4];
		output_map[342] = &cs->cwdc[5];
		output_map[343] = &cs->cwdc[6];
		output_map[344] = &cs->cwdc[7];
		output_map[345] = &cs->cwdc[8];
		output_map[346] = &cs->cwdc[9];
		output_map[347] = &cs->litr1c[0];
		output_map[348] = &cs->litr1c[1];
		output_map[349] = &cs->litr1c[2];
		output_map[350] = &cs->litr1c[3];
		output_map[351] = &cs->litr1c[4];
		output_map[352] = &cs->litr1c[5];
		output_map[353] = &cs->litr1c[6];
		output_map[354] = &cs->litr1c[7];
		output_map[355] = &cs->litr1c[8];
		output_map[356] = &cs->litr1c[9];
		output_map[357] = &cs->litr2c[0];
		output_map[358] = &cs->litr2c[1];
		output_map[359] = &cs->litr2c[2];
		output_map[360] = &cs->litr2c[3];
		output_map[361] = &cs->litr2c[4];
		output_map[362] = &cs->litr2c[5];
		output_map[363] = &cs->litr2c[6];
		output_map[364] = &cs->litr2c[7];
		output_map[365] = &cs->litr2c[8];
		output_map[366] = &cs->litr2c[9];
		output_map[367] = &cs->litr3c[0];
		output_map[368] = &cs->litr3c[1];
		output_map[369] = &cs->litr3c[2];
		output_map[370] = &cs->litr3c[3];
		output_map[371] = &cs->litr3c[4];
		output_map[372] = &cs->litr3c[5];
		output_map[373] = &cs->litr3c[6];
		output_map[374] = &cs->litr3c[7];
		output_map[375] = &cs->litr3c[8];
		output_map[376] = &cs->litr3c[9];
		output_map[377] = &cs->litr4c[0];
		output_map[378] = &cs->litr4c[1];
		output_map[379] = &cs->litr4c[2];
		output_map[380] = &cs->litr4c[3];
		output_map[381] = &cs->litr4c[4];
		output_map[382] = &cs->litr4c[5];
		output_map[383] = &cs->litr4c[6];
		output_map[384] = &cs->litr4c[7];
		output_map[385] = &cs->litr4c[8];
		output_map[386] = &cs->litr4c[9];
		output_map[387] = &cs->litrC[0];
		output_map[388] = &cs->litrC[1];
		output_map[389] = &cs->litrC[2];
		output_map[390] = &cs->litrC[3];
		output_map[391] = &cs->litrC[4];
		output_map[392] = &cs->litrC[5];
		output_map[393] = &cs->litrC[6];
		output_map[394] = &cs->litrC[7];
		output_map[395] = &cs->litrC[8];
		output_map[396] = &cs->litrC[9];
		output_map[397] = &cs->litr1c_total;
		output_map[398] = &cs->litr2c_total;
		output_map[399] = &cs->litr3c_total;
		output_map[400] = &cs->litr4c_total;
		output_map[401] = &cs->cwdc_total;
		output_map[402] = &cs->STDBc_leaf;
		output_map[403] = &cs->STDBc_froot;
		output_map[404] = &cs->STDBc_fruit;
		output_map[405] = &cs->STDBc_softstem;
		output_map[406] = &cs->STDBc_transfer;
		output_map[407] = &cs->STDBc_above;
		output_map[408] = &cs->STDBc_below;
		output_map[409] = &cs->CTDBc_leaf;
		output_map[410] = &cs->CTDBc_froot;
		output_map[411] = &cs->CTDBc_fruit;
		output_map[412] = &cs->CTDBc_softstem;
		output_map[413] = &cs->CTDBc_transfer;
		output_map[414] = &cs->CTDBc_cstem;
		output_map[415] = &cs->CTDBc_croot;
		output_map[416] = &cs->CTDBc_above;
		output_map[417] = &cs->CTDBc_below;
		output_map[418] = &cs->soil1c[0];
		output_map[419] = &cs->soil1c[1];
		output_map[420] = &cs->soil1c[2];
		output_map[421] = &cs->soil1c[3];
		output_map[422] = &cs->soil1c[4];
		output_map[423] = &cs->soil1c[5];
		output_map[424] = &cs->soil1c[6];
		output_map[425] = &cs->soil1c[7];
		output_map[426] = &cs->soil1c[8];
		output_map[427] = &cs->soil1c[9];
		output_map[428] = &cs->soil2c[0];
		output_map[429] = &cs->soil2c[1];
		output_map[430] = &cs->soil2c[2];
		output_map[431] = &cs->soil2c[3];
		output_map[432] = &cs->soil2c[4];
		output_map[433] = &cs->soil2c[5];
		output_map[434] = &cs->soil2c[6];
		output_map[435] = &cs->soil2c[7];
		output_map[436] = &cs->soil2c[8];
		output_map[437] = &cs->soil2c[9];
		output_map[438] = &cs->soil3c[0];
		output_map[439] = &cs->soil3c[1];
		output_map[440] = &cs->soil3c[2];
		output_map[441] = &cs->soil3c[3];
		output_map[442] = &cs->soil3c[4];
		output_map[443] = &cs->soil3c[5];
		output_map[444] = &cs->soil3c[6];
		output_map[445] = &cs->soil3c[7];
		output_map[446] = &cs->soil3c[8];
		output_map[447] = &cs->soil3c[9];
		output_map[448] = &cs->soil4c[0];
		output_map[449] = &cs->soil4c[1];
		output_map[450] = &cs->soil4c[2];
		output_map[451] = &cs->soil4c[3];
		output_map[452] = &cs->soil4c[4];
		output_map[453] = &cs->soil4c[5];
		output_map[454] = &cs->soil4c[6];
		output_map[455] = &cs->soil4c[7];
		output_map[456] = &cs->soil4c[8];
		output_map[457] = &cs->soil4c[9];
		output_map[458] = &cs->soilC[0];
		output_map[459] = &cs->soilC[1];
		output_map[460] = &cs->soilC[2];
		output_map[461] = &cs->soilC[3];
		output_map[462] = &cs->soilC[4];
		output_map[463] = &cs->soilC[5];
		output_map[464] = &cs->soilC[6];
		output_map[465] = &cs->soilC[7];
		output_map[466] = &cs->soilC[8];
		output_map[467] = &cs->soilC[9];
		output_map[468] = &cs->soil1_DOC[0];
		output_map[469] = &cs->soil1_DOC[1];
		output_map[470] = &cs->soil1_DOC[2];
		output_map[471] = &cs->soil1_DOC[3];
		output_map[472] = &cs->soil1_DOC[4];
		output_map[473] = &cs->soil1_DOC[5];
		output_map[474] = &cs->soil1_DOC[6];
		output_map[475] = &cs->soil1_DOC[7];
		output_map[476] = &cs->soil1_DOC[8];
		output_map[477] = &cs->soil1_DOC[9];
		output_map[478] = &cs->soil2_DOC[0];
		output_map[479] = &cs->soil2_DOC[1];
		output_map[480] = &cs->soil2_DOC[2];
		output_map[481] = &cs->soil2_DOC[3];
		output_map[482] = &cs->soil2_DOC[4];
		output_map[483] = &cs->soil2_DOC[5];
		output_map[484] = &cs->soil2_DOC[6];
		output_map[485] = &cs->soil2_DOC[7];
		output_map[486] = &cs->soil2_DOC[8];
		output_map[487] = &cs->soil2_DOC[9];
		output_map[488] = &cs->soil3_DOC[0];
		output_map[489] = &cs->soil3_DOC[1];
		output_map[490] = &cs->soil3_DOC[2];
		output_map[491] = &cs->soil3_DOC[3];
		output_map[492] = &cs->soil3_DOC[4];
		output_map[493] = &cs->soil3_DOC[5];
		output_map[494] = &cs->soil3_DOC[6];
		output_map[495] = &cs->soil3_DOC[7];
		output_map[496] = &cs->soil3_DOC[8];
		output_map[497] = &cs->soil3_DOC[9];
		output_map[498] = &cs->soil4_DOC[0];
		output_map[499] = &cs->soil4_DOC[1];
		output_map[500] = &cs->soil4_DOC[2];
		output_map[501] = &cs->soil4_DOC[3];
		output_map[502] = &cs->soil4_DOC[4];
		output_map[503] = &cs->soil4_DOC[5];
		output_map[504] = &cs->soil4_DOC[6];
		output_map[505] = &cs->soil4_DOC[7];
		output_map[506] = &cs->soil4_DOC[8];
		output_map[507] = &cs->soil4_DOC[9];
		output_map[508] = &cs->soil_DOC[0];
		output_map[509] = &cs->soil_DOC[1];
		output_map[510] = &cs->soil_DOC[2];
		output_map[511] = &cs->soil_DOC[3];
		output_map[512] = &cs->soil_DOC[4];
		output_map[513] = &cs->soil_DOC[5];
		output_map[514] = &cs->soil_DOC[6];
		output_map[515] = &cs->soil_DOC[7];
		output_map[516] = &cs->soil_DOC[8];
		output_map[517] = &cs->soil_DOC[9];
		output_map[518] = &cs->soil1c_total;
		output_map[519] = &cs->soil2c_total;
		output_map[520] = &cs->soil3c_total;
		output_map[521] = &cs->soil4c_total;
		output_map[522] = &cs->cpool;
		output_map[523] = &cs->psnsun_src;
		output_map[524] = &cs->psnshade_src;
		output_map[525] = &cs->NSC_mr_snk;
		output_map[526] = &cs->actC_mr_snk;
		output_map[527] = &cs->leaf_mr_snk;
		output_map[528] = &cs->froot_mr_snk;
		output_map[529] = &cs->fruit_mr_snk;
		output_map[530] = &cs->softstem_mr_snk;
		output_map[531] = &cs->livestem_mr_snk;
		output_map[532] = &cs->livecroot_mr_snk;
		output_map[533] = &cs->leaf_gr_snk;
		output_map[534] = &cs->froot_gr_snk;
		output_map[535] = &cs->fruit_gr_snk;
		output_map[536] = &cs->softstem_gr_snk;
		output_map[537] = &cs->livestem_gr_snk;
		output_map[538] = &cs->livecroot_gr_snk;
		output_map[539] = &cs->deadstem_gr_snk;
		output_map[540] = &cs->deadcroot_gr_snk;
		output_map[541] = &cs->litr1_hr_snk;
		output_map[542] = &cs->litr2_hr_snk;
		output_map[543] = &cs->litr4_hr_snk;
		output_map[544] = &cs->soil1_hr_snk;
		output_map[545] = &cs->soil2_hr_snk;
		output_map[546] = &cs->soil3_hr_snk;
		output_map[547] = &cs->soil4_hr_snk;
		output_map[548] = &cs->fire_snk;
		output_map[549] = &cs->SNSCsnk;
		output_map[550] = &cs->PLTsrc;
		output_map[551] = &cs->THN_transportC;
		output_map[552] = &cs->HRV_transportC;
		output_map[553] = &cs->MOW_transportC;
		output_map[554] = &cs->GRZsnk;
		output_map[555] = &cs->GRZsrc;
		output_map[556] = &cs->FRZsrc;
		output_map[557] = &cs->balanceERR;
		output_map[558] = &cs->in;
		output_map[559] = &cs->out;
		output_map[560] = &cs->store;
		output_map[600] = &cf->m_leafc_to_litr1c;
		output_map[601] = &cf->m_leafc_to_litr2c;
		output_map[602] = &cf->m_leafc_to_litr3c;
		output_map[603] = &cf->m_leafc_to_litr4c;
		output_map[604] = &cf->m_frootc_to_litr1c;
		output_map[605] = &cf->m_frootc_to_litr2c;
		output_map[606] = &cf->m_frootc_to_litr3c;
		output_map[607] = &cf->m_frootc_to_litr4c;
		output_map[608] = &cf->m_fruitc_to_litr1c;
		output_map[609] = &cf->m_fruitc_to_litr2c;
		output_map[610] = &cf->m_fruitc_to_litr3c;
		output_map[611] = &cf->m_fruitc_to_litr4c;
		output_map[612] = &cf->m_softstemc_to_litr1c;
		output_map[613] = &cf->m_softstemc_to_litr2c;
		output_map[614] = &cf->m_softstemc_to_litr3c;
		output_map[615] = &cf->m_softstemc_to_litr4c;
		output_map[616] = &cf->m_leafc_storage_to_litr1c;
		output_map[617] = &cf->m_frootc_storage_to_litr1c;
		output_map[618] = &cf->m_softstemc_storage_to_litr1c;
		output_map[619] = &cf->m_fruitc_storage_to_litr1c;
		output_map[620] = &cf->m_livestemc_storage_to_litr1c;
		output_map[621] = &cf->m_deadstemc_storage_to_litr1c;
		output_map[622] = &cf->m_livecrootc_storage_to_litr1c;
		output_map[623] = &cf->m_deadcrootc_storage_to_litr1c;
		output_map[624] = &cf->m_leafc_transfer_to_litr1c;
		output_map[625] = &cf->m_frootc_transfer_to_litr1c;
		output_map[626] = &cf->m_fruitc_transfer_to_litr1c;
		output_map[627] = &cf->m_softstemc_transfer_to_litr1c;
		output_map[628] = &cf->m_livestemc_transfer_to_litr1c;
		output_map[629] = &cf->m_deadstemc_transfer_to_litr1c;
		output_map[630] = &cf->m_livecrootc_transfer_to_litr1c;
		output_map[631] = &cf->m_deadcrootc_transfer_to_litr1c;
		output_map[632] = &cf->m_livestemc_to_cwdc;
		output_map[633] = &cf->m_deadstemc_to_cwdc;
		output_map[634] = &cf->m_livecrootc_to_cwdc;
		output_map[635] = &cf->m_deadcrootc_to_cwdc;
		output_map[636] = &cf->m_gresp_storage_to_litr1c;
		output_map[637] = &cf->m_gresp_transfer_to_litr1c;
		output_map[638] = &cf->m_leafc_to_fire;
		output_map[639] = &cf->m_frootc_to_fire;
		output_map[640] = &cf->m_fruitc_to_fire;
		output_map[641] = &cf->m_softstemc_to_fire;
		output_map[642] = &cf->m_STDBc_to_fire;
		output_map[643] = &cf->m_CTDBc_to_fire;
		output_map[644] = &cf->m_leafc_storage_to_fire;
		output_map[645] = &cf->m_frootc_storage_to_fire;
		output_map[646] = &cf->m_fruitc_storage_to_fire;
		output_map[647] = &cf->m_softstemc_storage_to_fire;
		output_map[648] = &cf->m_livestemc_storage_to_fire;
		output_map[649] = &cf->m_deadstemc_storage_to_fire;
		output_map[650] = &cf->m_livecrootc_storage_to_fire;
		output_map[651] = &cf->m_deadcrootc_storage_to_fire;
		output_map[652] = &cf->m_leafc_transfer_to_fire;
		output_map[653] = &cf->m_frootc_transfer_to_fire;
		output_map[654] = &cf->m_fruitc_transfer_to_fire;
		output_map[655] = &cf->m_softstemc_transfer_to_fire;
		output_map[656] = &cf->m_livestemc_transfer_to_fire;
		output_map[657] = &cf->m_deadstemc_transfer_to_fire;
		output_map[658] = &cf->m_livecrootc_transfer_to_fire;
		output_map[659] = &cf->m_deadcrootc_transfer_to_fire;
		output_map[660] = &cf->m_livestemc_to_fire;
		output_map[661] = &cf->m_deadstemc_to_fire;
		output_map[662] = &cf->m_livecrootc_to_fire;
		output_map[663] = &cf->m_deadcrootc_to_fire;
		output_map[664] = &cf->m_gresp_storage_to_fire;
		output_map[665] = &cf->m_gresp_transfer_to_fire;
		output_map[666] = &cf->m_litr1c_to_fire;
		output_map[667] = &cf->m_litr2c_to_fire;
		output_map[668] = &cf->m_litr3c_to_fire;
		output_map[669] = &cf->m_litr4c_to_fire;
		output_map[670] = &cf->m_cwdc_to_fire;
		output_map[671] = &cf->m_vegc_to_SNSC;
		output_map[672] = &cf->m_leafc_to_SNSC;
		output_map[673] = &cf->m_leafc_to_SNSCgenprog;
		output_map[674] = &cf->m_frootc_to_SNSC;
		output_map[675] = &cf->m_fruitc_to_SNSC;
		output_map[676] = &cf->m_softstemc_to_SNSC;
		output_map[677] = &cf->m_leafc_storage_to_SNSC;
		output_map[678] = &cf->m_frootc_storage_to_SNSC;
		output_map[679] = &cf->m_leafc_transfer_to_SNSC;
		output_map[680] = &cf->m_frootc_transfer_to_SNSC;
		output_map[681] = &cf->m_fruitc_storage_to_SNSC;
		output_map[682] = &cf->m_fruitc_transfer_to_SNSC;
		output_map[683] = &cf->m_softstemc_storage_to_SNSC;
		output_map[684] = &cf->m_softstemc_transfer_to_SNSC;
		output_map[685] = &cf->m_gresp_storage_to_SNSC;
		output_map[686] = &cf->m_gresp_transfer_to_SNSC;
		output_map[687] = &cf->HRV_leafc_storage_to_SNSC;
		output_map[688] = &cf->HRV_leafc_transfer_to_SNSC;
		output_map[689] = &cf->HRV_fruitc_storage_to_SNSC;
		output_map[690] = &cf->HRV_fruitc_transfer_to_SNSC;
		output_map[691] = &cf->HRV_frootc_to_SNSC;
		output_map[692] = &cf->HRV_softstemc_to_SNSC;
		output_map[693] = &cf->HRV_frootc_storage_to_SNSC;
		output_map[694] = &cf->HRV_frootc_transfer_to_SNSC;
		output_map[695] = &cf->HRV_softstemc_storage_to_SNSC;
		output_map[696] = &cf->HRV_softstemc_transfer_to_SNSC;
		output_map[697] = &cf->HRV_gresp_storage_to_SNSC;
		output_map[698] = &cf->HRV_gresp_transfer_to_SNSC;
		output_map[699] = &cf->fruitc_to_flowHS;
		output_map[700] = &cf->STDBc_leaf_to_litr;
		output_map[701] = &cf->STDBc_froot_to_litr;
		output_map[702] = &cf->STDBc_fruit_to_litr;
		output_map[703] = &cf->STDBc_softstem_to_litr;
		output_map[704] = &cf->STDBc_transfer_to_litr;
		output_map[705] = &cf->STDBc_to_litr;
		output_map[706] = &cf->CTDBc_leaf_to_litr;
		output_map[707] = &cf->CTDBc_froot_to_litr;
		output_map[708] = &cf->CTDBc_fruit_to_litr;
		output_map[709] = &cf->CTDBc_softstem_to_litr;
		output_map[710] = &cf->CTDBc_transfer_to_litr;
		output_map[711] = &cf->CTDBc_cstem_to_cwd;
		output_map[712] = &cf->CTDBc_croot_to_cwd;
		output_map[713] = &cf->CTDBc_to_litr;
		output_map[714] = &cf->leafc_transfer_to_leafc;
		output_map[715] = &cf->frootc_transfer_to_frootc;
		output_map[716] = &cf->fruitc_transfer_to_fruitc;
		output_map[717] = &cf->softstemc_transfer_to_softstemc;
		output_map[718] = &cf->livestemc_transfer_to_livestemc;
		output_map[719] = &cf->deadstemc_transfer_to_deadstemc;
		output_map[720] = &cf->livecrootc_transfer_to_livecrootc;
		output_map[721] = &cf->deadcrootc_transfer_to_deadcrootc;
		output_map[722] = &cf->leafc_to_litr1c;
		output_map[723] = &cf->leafc_to_litr2c;
		output_map[724] = &cf->leafc_to_litr3c;
		output_map[725] = &cf->leafc_to_litr4c;
		output_map[726] = &cf->frootc_to_litr1c;
		output_map[727] = &cf->frootc_to_litr2c;
		output_map[728] = &cf->frootc_to_litr3c;
		output_map[729] = &cf->frootc_to_litr4c;
		output_map[730] = &cf->fruitc_to_litr1c;
		output_map[731] = &cf->fruitc_to_litr2c;
		output_map[732] = &cf->fruitc_to_litr3c;
		output_map[733] = &cf->fruitc_to_litr4c;
		output_map[734] = &cf->softstemc_to_litr1c;
		output_map[735] = &cf->softstemc_to_litr2c;
		output_map[736] = &cf->softstemc_to_litr3c;
		output_map[737] = &cf->softstemc_to_litr4c;
		output_map[738] = &cf->leaf_day_mr;
		output_map[739] = &cf->leaf_night_mr;
		output_map[740] = &cf->froot_mr;
		output_map[741] = &cf->fruit_mr;
		output_map[742] = &cf->softstem_mr;
		output_map[743] = &cf->livestem_mr;
		output_map[744] = &cf->livecroot_mr;
		output_map[745] = &cf->psnsun_to_cpool;
		output_map[746] = &cf->psnshade_to_cpool;
		output_map[747] = &cf->cwdc_to_litr2c[0];
		output_map[748] = &cf->cwdc_to_litr2c[1];
		output_map[749] = &cf->cwdc_to_litr2c[2];
		output_map[750] = &cf->cwdc_to_litr2c[3];
		output_map[751] = &cf->cwdc_to_litr2c[4];
		output_map[752] = &cf->cwdc_to_litr2c[5];
		output_map[753] = &cf->cwdc_to_litr2c[6];
		output_map[754] = &cf->cwdc_to_litr2c[7];
		output_map[755] = &cf->cwdc_to_litr2c[8];
		output_map[756] = &cf->cwdc_to_litr2c[9];
		output_map[757] = &cf->cwdc_to_litr3c[0];
		output_map[758] = &cf->cwdc_to_litr3c[1];
		output_map[759] = &cf->cwdc_to_litr3c[2];
		output_map[760] = &cf->cwdc_to_litr3c[3];
		output_map[761] = &cf->cwdc_to_litr3c[4];
		output_map[762] = &cf->cwdc_to_litr3c[5];
		output_map[763] = &cf->cwdc_to_litr3c[6];
		output_map[764] = &cf->cwdc_to_litr3c[7];
		output_map[765] = &cf->cwdc_to_litr3c[8];
		output_map[766] = &cf->cwdc_to_litr3c[9];
		output_map[767] = &cf->cwdc_to_litr4c[0];
		output_map[768] = &cf->cwdc_to_litr4c[1];
		output_map[769] = &cf->cwdc_to_litr4c[2];
		output_map[770] = &cf->cwdc_to_litr4c[3];
		output_map[771] = &cf->cwdc_to_litr4c[4];
		output_map[772] = &cf->cwdc_to_litr4c[5];
		output_map[773] = &cf->cwdc_to_litr4c[6];
		output_map[774] = &cf->cwdc_to_litr4c[7];
		output_map[775] = &cf->cwdc_to_litr4c[8];
		output_map[776] = &cf->cwdc_to_litr4c[9];
		output_map[777] = &cf->litr1_hr[0];
		output_map[778] = &cf->litr1_hr[1];
		output_map[779] = &cf->litr1_hr[2];
		output_map[780] = &cf->litr1_hr[3];
		output_map[781] = &cf->litr1_hr[4];
		output_map[782] = &cf->litr1_hr[5];
		output_map[783] = &cf->litr1_hr[6];
		output_map[784] = &cf->litr1_hr[7];
		output_map[785] = &cf->litr1_hr[8];
		output_map[786] = &cf->litr1_hr[9];
		output_map[787] = &cf->litr1c_to_soil1c[0];
		output_map[788] = &cf->litr1c_to_soil1c[1];
		output_map[789] = &cf->litr1c_to_soil1c[2];
		output_map[790] = &cf->litr1c_to_soil1c[3];
		output_map[791] = &cf->litr1c_to_soil1c[4];
		output_map[792] = &cf->litr1c_to_soil1c[5];
		output_map[793] = &cf->litr1c_to_soil1c[6];
		output_map[794] = &cf->litr1c_to_soil1c[7];
		output_map[795] = &cf->litr1c_to_soil1c[8];
		output_map[796] = &cf->litr1c_to_soil1c[9];
		output_map[797] = &cf->litr2_hr[0];
		output_map[798] = &cf->litr2_hr[1];
		output_map[799] = &cf->litr2_hr[2];
		output_map[800] = &cf->litr2_hr[3];
		output_map[801] = &cf->litr2_hr[4];
		output_map[802] = &cf->litr2_hr[5];
		output_map[803] = &cf->litr2_hr[6];
		output_map[804] = &cf->litr2_hr[7];
		output_map[805] = &cf->litr2_hr[8];
		output_map[806] = &cf->litr2_hr[9];
		output_map[807] = &cf->litr2c_to_soil2c[0];
		output_map[808] = &cf->litr2c_to_soil2c[1];
		output_map[809] = &cf->litr2c_to_soil2c[2];
		output_map[810] = &cf->litr2c_to_soil2c[3];
		output_map[811] = &cf->litr2c_to_soil2c[4];
		output_map[812] = &cf->litr2c_to_soil2c[5];
		output_map[813] = &cf->litr2c_to_soil2c[6];
		output_map[814] = &cf->litr2c_to_soil2c[7];
		output_map[815] = &cf->litr2c_to_soil2c[8];
		output_map[816] = &cf->litr2c_to_soil2c[9];
		output_map[817] = &cf->litr3c_to_litr2c[0];
		output_map[818] = &cf->litr3c_to_litr2c[1];
		output_map[819] = &cf->litr3c_to_litr2c[2];
		output_map[820] = &cf->litr3c_to_litr2c[3];
		output_map[821] = &cf->litr3c_to_litr2c[4];
		output_map[822] = &cf->litr3c_to_litr2c[5];
		output_map[823] = &cf->litr3c_to_litr2c[6];
		output_map[824] = &cf->litr3c_to_litr2c[7];
		output_map[825] = &cf->litr3c_to_litr2c[8];
		output_map[826] = &cf->litr3c_to_litr2c[9];
		output_map[827] = &cf->litr4_hr[0];
		output_map[828] = &cf->litr4_hr[1];
		output_map[829] = &cf->litr4_hr[2];
		output_map[830] = &cf->litr4_hr[3];
		output_map[831] = &cf->litr4_hr[4];
		output_map[832] = &cf->litr4_hr[5];
		output_map[833] = &cf->litr4_hr[6];
		output_map[834] = &cf->litr4_hr[7];
		output_map[835] = &cf->litr4_hr[8];
		output_map[836] = &cf->litr4_hr[9];
		output_map[837] = &cf->litr4c_to_soil3c[0];
		output_map[838] = &cf->litr4c_to_soil3c[1];
		output_map[839] = &cf->litr4c_to_soil3c[2];
		output_map[840] = &cf->litr4c_to_soil3c[3];
		output_map[841] = &cf->litr4c_to_soil3c[4];
		output_map[842] = &cf->litr4c_to_soil3c[5];
		output_map[843] = &cf->litr4c_to_soil3c[6];
		output_map[844] = &cf->litr4c_to_soil3c[7];
		output_map[845] = &cf->litr4c_to_soil3c[8];
		output_map[846] = &cf->litr4c_to_soil3c[9];
		output_map[847] = &cf->soil1_hr[0];
		output_map[848] = &cf->soil1_hr[1];
		output_map[849] = &cf->soil1_hr[2];
		output_map[850] = &cf->soil1_hr[3];
		output_map[851] = &cf->soil1_hr[4];
		output_map[852] = &cf->soil1_hr[5];
		output_map[853] = &cf->soil1_hr[6];
		output_map[854] = &cf->soil1_hr[7];
		output_map[855] = &cf->soil1_hr[8];
		output_map[856] = &cf->soil1_hr[9];
		output_map[857] = &cf->soil1c_to_soil2c[0];
		output_map[858] = &cf->soil1c_to_soil2c[1];
		output_map[859] = &cf->soil1c_to_soil2c[2];
		output_map[860] = &cf->soil1c_to_soil2c[3];
		output_map[861] = &cf->soil1c_to_soil2c[4];
		output_map[862] = &cf->soil1c_to_soil2c[5];
		output_map[863] = &cf->soil1c_to_soil2c[6];
		output_map[864] = &cf->soil1c_to_soil2c[7];
		output_map[865] = &cf->soil1c_to_soil2c[8];
		output_map[866] = &cf->soil1c_to_soil2c[9];
		output_map[867] = &cf->soil2_hr[0];
		output_map[868] = &cf->soil2_hr[1];
		output_map[869] = &cf->soil2_hr[2];
		output_map[870] = &cf->soil2_hr[3];
		output_map[871] = &cf->soil2_hr[4];
		output_map[872] = &cf->soil2_hr[5];
		output_map[873] = &cf->soil2_hr[6];
		output_map[874] = &cf->soil2_hr[7];
		output_map[875] = &cf->soil2_hr[8];
		output_map[876] = &cf->soil2_hr[9];
		output_map[877] = &cf->soil2c_to_soil3c[0];
		output_map[878] = &cf->soil2c_to_soil3c[1];
		output_map[879] = &cf->soil2c_to_soil3c[2];
		output_map[880] = &cf->soil2c_to_soil3c[3];
		output_map[881] = &cf->soil2c_to_soil3c[4];
		output_map[882] = &cf->soil2c_to_soil3c[5];
		output_map[883] = &cf->soil2c_to_soil3c[6];
		output_map[884] = &cf->soil2c_to_soil3c[7];
		output_map[885] = &cf->soil2c_to_soil3c[8];
		output_map[886] = &cf->soil2c_to_soil3c[9];
		output_map[887] = &cf->soil3_hr[0];
		output_map[888] = &cf->soil3_hr[1];
		output_map[889] = &cf->soil3_hr[2];
		output_map[890] = &cf->soil3_hr[3];
		output_map[891] = &cf->soil3_hr[4];
		output_map[892] = &cf->soil3_hr[5];
		output_map[893] = &cf->soil3_hr[6];
		output_map[894] = &cf->soil3_hr[7];
		output_map[895] = &cf->soil3_hr[8];
		output_map[896] = &cf->soil3_hr[9];
		output_map[897] = &cf->soil3c_to_soil4c[0];
		output_map[898] = &cf->soil3c_to_soil4c[1];
		output_map[899] = &cf->soil3c_to_soil4c[2];
		output_map[900] = &cf->soil3c_to_soil4c[3];
		output_map[901] = &cf->soil3c_to_soil4c[4];
		output_map[902] = &cf->soil3c_to_soil4c[5];
		output_map[903] = &cf->soil3c_to_soil4c[6];
		output_map[904] = &cf->soil3c_to_soil4c[7];
		output_map[905] = &cf->soil3c_to_soil4c[8];
		output_map[906] = &cf->soil3c_to_soil4c[9];
		output_map[907] = &cf->soil4_hr[0];
		output_map[908] = &cf->soil4_hr[1];
		output_map[909] = &cf->soil4_hr[2];
		output_map[910] = &cf->soil4_hr[3];
		output_map[911] = &cf->soil4_hr[4];
		output_map[912] = &cf->soil4_hr[5];
		output_map[913] = &cf->soil4_hr[6];
		output_map[914] = &cf->soil4_hr[7];
		output_map[915] = &cf->soil4_hr[8];
		output_map[916] = &cf->soil4_hr[9];
		output_map[917] = &cf->soil1_DOC_leached[0];
		output_map[918] = &cf->soil1_DOC_leached[1];
		output_map[919] = &cf->soil1_DOC_leached[2];
		output_map[920] = &cf->soil1_DOC_leached[3];
		output_map[921] = &cf->soil1_DOC_leached[4];
		output_map[922] = &cf->soil1_DOC_leached[5];
		output_map[923] = &cf->soil1_DOC_leached[6];
		output_map[924] = &cf->soil1_DOC_leached[7];
		output_map[925] = &cf->soil1_DOC_leached[8];
		output_map[926] = &cf->soil1_DOC_leached[9];
		output_map[927] = &cf->soil2_DOC_leached[0];
		output_map[928] = &cf->soil2_DOC_leached[1];
		output_map[929] = &cf->soil2_DOC_leached[2];
		output_map[930] = &cf->soil2_DOC_leached[3];
		output_map[931] = &cf->soil2_DOC_leached[4];
		output_map[932] = &cf->soil2_DOC_leached[5];
		output_map[933] = &cf->soil2_DOC_leached[6];
		output_map[934] = &cf->soil2_DOC_leached[7];
		output_map[935] = &cf->soil2_DOC_leached[8];
		output_map[936] = &cf->soil2_DOC_leached[9];
		output_map[937] = &cf->soil3_DOC_leached[0];
		output_map[938] = &cf->soil3_DOC_leached[1];
		output_map[939] = &cf->soil3_DOC_leached[2];
		output_map[940] = &cf->soil3_DOC_leached[3];
		output_map[941] = &cf->soil3_DOC_leached[4];
		output_map[942] = &cf->soil3_DOC_leached[5];
		output_map[943] = &cf->soil3_DOC_leached[6];
		output_map[944] = &cf->soil3_DOC_leached[7];
		output_map[945] = &cf->soil3_DOC_leached[8];
		output_map[946] = &cf->soil3_DOC_leached[9];
		output_map[947] = &cf->soil4_DOC_leached[0];
		output_map[948] = &cf->soil4_DOC_leached[1];
		output_map[949] = &cf->soil4_DOC_leached[2];
		output_map[950] = &cf->soil4_DOC_leached[3];
		output_map[951] = &cf->soil4_DOC_leached[4];
		output_map[952] = &cf->soil4_DOC_leached[5];
		output_map[953] = &cf->soil4_DOC_leached[6];
		output_map[954] = &cf->soil4_DOC_leached[7];
		output_map[955] = &cf->soil4_DOC_leached[8];
		output_map[956] = &cf->soil4_DOC_leached[9];
		output_map[957] = &cf->soil1_DOC_diffused[0];
		output_map[958] = &cf->soil1_DOC_diffused[1];
		output_map[959] = &cf->soil1_DOC_diffused[2];
		output_map[960] = &cf->soil1_DOC_diffused[3];
		output_map[961] = &cf->soil1_DOC_diffused[4];
		output_map[962] = &cf->soil1_DOC_diffused[5];
		output_map[963] = &cf->soil1_DOC_diffused[6];
		output_map[964] = &cf->soil1_DOC_diffused[7];
		output_map[965] = &cf->soil1_DOC_diffused[8];
		output_map[966] = &cf->soil1_DOC_diffused[9];
		output_map[967] = &cf->soil2_DOC_diffused[0];
		output_map[968] = &cf->soil2_DOC_diffused[1];
		output_map[969] = &cf->soil2_DOC_diffused[2];
		output_map[970] = &cf->soil2_DOC_diffused[3];
		output_map[971] = &cf->soil2_DOC_diffused[4];
		output_map[972] = &cf->soil2_DOC_diffused[5];
		output_map[973] = &cf->soil2_DOC_diffused[6];
		output_map[974] = &cf->soil2_DOC_diffused[7];
		output_map[975] = &cf->soil2_DOC_diffused[8];
		output_map[976] = &cf->soil2_DOC_diffused[9];
		output_map[977] = &cf->soil3_DOC_diffused[0];
		output_map[978] = &cf->soil3_DOC_diffused[1];
		output_map[979] = &cf->soil3_DOC_diffused[2];
		output_map[980] = &cf->soil3_DOC_diffused[3];
		output_map[981] = &cf->soil3_DOC_diffused[4];
		output_map[982] = &cf->soil3_DOC_diffused[5];
		output_map[983] = &cf->soil3_DOC_diffused[6];
		output_map[984] = &cf->soil3_DOC_diffused[7];
		output_map[985] = &cf->soil3_DOC_diffused[8];
		output_map[986] = &cf->soil3_DOC_diffused[9];
		output_map[987] = &cf->soil4_DOC_diffused[0];
		output_map[988] = &cf->soil4_DOC_diffused[1];
		output_map[989] = &cf->soil4_DOC_diffused[2];
		output_map[990] = &cf->soil4_DOC_diffused[3];
		output_map[991] = &cf->soil4_DOC_diffused[4];
		output_map[992] = &cf->soil4_DOC_diffused[5];
		output_map[993] = &cf->soil4_DOC_diffused[6];
		output_map[994] = &cf->soil4_DOC_diffused[7];
		output_map[995] = &cf->soil4_DOC_diffused[8];
		output_map[996] = &cf->soil4_DOC_diffused[9];
		output_map[997] = &cf->DOC_rootzone_leach;
		output_map[998] = &cf->cpool_to_leafc;
		output_map[999] = &cf->cpool_to_leafc_storage;
		output_map[1000] = &cf->cpool_to_frootc;
		output_map[1001] = &cf->cpool_to_frootc_storage;
		output_map[1002] = &cf->cpool_to_fruitc;
		output_map[1003] = &cf->cpool_to_fruitc_storage;
		output_map[1004] = &cf->cpool_to_softstemc;
		output_map[1005] = &cf->cpool_to_softstemc_storage;
		output_map[1006] = &cf->cpool_to_livestemc;
		output_map[1007] = &cf->cpool_to_livestemc_storage;
		output_map[1008] = &cf->cpool_to_deadstemc;
		output_map[1009] = &cf->cpool_to_deadstemc_storage;
		output_map[1010] = &cf->cpool_to_livecrootc;
		output_map[1011] = &cf->cpool_to_livecrootc_storage;
		output_map[1012] = &cf->cpool_to_deadcrootc;
		output_map[1013] = &cf->cpool_to_deadcrootc_storage;
		output_map[1014] = &cf->cpool_to_gresp_storage;
		output_map[1015] = &cf->cpool_leaf_gr;
		output_map[1016] = &cf->cpool_leaf_storage_gr;
		output_map[1017] = &cf->transfer_leaf_gr;
		output_map[1018] = &cf->cpool_froot_gr;
		output_map[1019] = &cf->cpool_froot_storage_gr;
		output_map[1020] = &cf->transfer_froot_gr;
		output_map[1021] = &cf->cpool_fruit_gr;
		output_map[1022] = &cf->cpool_fruit_storage_gr;
		output_map[1023] = &cf->transfer_fruit_gr;
		output_map[1024] = &cf->cpool_softstem_gr;
		output_map[1025] = &cf->cpool_softstem_storage_gr;
		output_map[1026] = &cf->transfer_softstem_gr;
		output_map[1027] = &cf->cpool_livestem_gr;
		output_map[1028] = &cf->cpool_livestem_storage_gr;
		output_map[1029] = &cf->transfer_livestem_gr;
		output_map[1030] = &cf->cpool_deadstem_gr;
		output_map[1031] = &cf->cpool_deadstem_storage_gr;
		output_map[1032] = &cf->transfer_deadstem_gr;
		output_map[1033] = &cf->cpool_livecroot_gr;
		output_map[1034] = &cf->cpool_livecroot_storage_gr;
		output_map[1035] = &cf->transfer_livecroot_gr;
		output_map[1036] = &cf->cpool_deadcroot_gr;
		output_map[1037] = &cf->cpool_deadcroot_storage_gr;
		output_map[1038] = &cf->transfer_deadcroot_gr;
		output_map[1039] = &cf->leafc_storage_to_maintresp;
		output_map[1040] = &cf->frootc_storage_to_maintresp;
		output_map[1041] = &cf->fruitc_storage_to_maintresp;
		output_map[1042] = &cf->softstemc_storage_to_maintresp;
		output_map[1043] = &cf->livestemc_storage_to_maintresp;
		output_map[1044] = &cf->livecrootc_storage_to_maintresp;
		output_map[1045] = &cf->deadstemc_storage_to_maintresp;
		output_map[1046] = &cf->deadcrootc_storage_to_maintresp;
		output_map[1047] = &cf->leafc_transfer_to_maintresp;
		output_map[1048] = &cf->frootc_transfer_to_maintresp;
		output_map[1049] = &cf->fruitc_transfer_to_maintresp;
		output_map[1050] = &cf->softstemc_transfer_to_maintresp;
		output_map[1051] = &cf->livestemc_transfer_to_maintresp;
		output_map[1052] = &cf->livecrootc_transfer_to_maintresp;
		output_map[1053] = &cf->deadstemc_transfer_to_maintresp;
		output_map[1054] = &cf->deadcrootc_transfer_to_maintresp;
		output_map[1055] = &cf->leafc_to_maintresp;
		output_map[1056] = &cf->frootc_to_maintresp;
		output_map[1057] = &cf->fruitc_to_maintresp;
		output_map[1058] = &cf->softstemc_to_maintresp;
		output_map[1059] = &cf->livestemc_to_maintresp;
		output_map[1060] = &cf->livecrootc_to_maintresp;
		output_map[1061] = &cf->NSC_nw_to_maintresp;
		output_map[1062] = &cf->actC_nw_to_maintresp;
		output_map[1063] = &cf->NSC_w_to_maintresp;
		output_map[1064] = &cf->actC_w_to_maintresp;
		output_map[1065] = &cf->leafc_storage_to_leafc_transfer;
		output_map[1066] = &cf->frootc_storage_to_frootc_transfer;
		output_map[1067] = &cf->fruitc_storage_to_fruitc_transfer;
		output_map[1068] = &cf->softstemc_storage_to_softstemc_transfer;
		output_map[1069] = &cf->livestemc_storage_to_livestemc_transfer;
		output_map[1070] = &cf->deadstemc_storage_to_deadstemc_transfer;
		output_map[1071] = &cf->livecrootc_storage_to_livecrootc_transfer;
		output_map[1072] = &cf->deadcrootc_storage_to_deadcrootc_transfer;
		output_map[1073] = &cf->gresp_storage_to_gresp_transfer;
		output_map[1074] = &cf->livestemc_to_deadstemc;
		output_map[1075] = &cf->livecrootc_to_deadcrootc;
		output_map[1076] = &cf->leafc_transfer_from_PLT;
		output_map[1077] = &cf->frootc_transfer_from_PLT;
		output_map[1078] = &cf->fruitc_transfer_from_PLT;
		output_map[1079] = &cf->softstemc_transfer_from_PLT;
		output_map[1080] = &cf->leafc_to_THN;
		output_map[1081] = &cf->leafc_storage_to_THN;
		output_map[1082] = &cf->leafc_transfer_to_THN;
		output_map[1083] = &cf->fruitc_to_THN;
		output_map[1084] = &cf->fruitc_storage_to_THN;
		output_map[1085] = &cf->fruitc_transfer_to_THN;
		output_map[1086] = &cf->livestemc_to_THN;
		output_map[1087] = &cf->livestemc_storage_to_THN;
		output_map[1088] = &cf->livestemc_transfer_to_THN;
		output_map[1089] = &cf->deadstemc_to_THN;
		output_map[1090] = &cf->deadstemc_storage_to_THN;
		output_map[1091] = &cf->deadstemc_transfer_to_THN;
		output_map[1092] = &cf->gresp_storage_to_THN;
		output_map[1093] = &cf->gresp_transfer_to_THN;
		output_map[1094] = &cf->THN_to_CTDBc_leaf;
		output_map[1095] = &cf->THN_to_CTDBc_fruit;
		output_map[1096] = &cf->THN_to_CTDBc_transfer;
		output_map[1097] = &cf->THN_to_CTDBc_cstem;
		output_map[1098] = &cf->STDBc_leaf_to_THN;
		output_map[1099] = &cf->STDBc_fruit_to_THN;
		output_map[1100] = &cf->STDBc_transfer_to_THN;
		output_map[1101] = &cf->leafc_to_MOW;
		output_map[1102] = &cf->leafc_storage_to_MOW;
		output_map[1103] = &cf->leafc_transfer_to_MOW;
		output_map[1104] = &cf->fruitc_to_MOW;
		output_map[1105] = &cf->fruitc_storage_to_MOW;
		output_map[1106] = &cf->fruitc_transfer_to_MOW;
		output_map[1107] = &cf->softstemc_to_MOW;
		output_map[1108] = &cf->softstemc_storage_to_MOW;
		output_map[1109] = &cf->softstemc_transfer_to_MOW;
		output_map[1110] = &cf->gresp_storage_to_MOW;
		output_map[1111] = &cf->gresp_transfer_to_MOW;
		output_map[1112] = &cf->MOW_to_CTDBc_leaf;
		output_map[1113] = &cf->MOW_to_CTDBc_fruit;
		output_map[1114] = &cf->MOW_to_CTDBc_softstem;
		output_map[1115] = &cf->MOW_to_CTDBc_transfer;
		output_map[1116] = &cf->STDBc_leaf_to_MOW;
		output_map[1117] = &cf->STDBc_fruit_to_MOW;
		output_map[1118] = &cf->STDBc_softstem_to_MOW;
		output_map[1119] = &cf->STDBc_transfer_to_MOW;
		output_map[1120] = &cf->leafc_to_HRV;
		output_map[1121] = &cf->leafc_storage_to_HRV;
		output_map[1122] = &cf->leafc_transfer_to_HRV;
		output_map[1123] = &cf->fruitc_to_HRV;
		output_map[1124] = &cf->fruitc_storage_to_HRV;
		output_map[1125] = &cf->fruitc_transfer_to_HRV;
		output_map[1126] = &cf->softstemc_to_HRV;
		output_map[1127] = &cf->softstemc_storage_to_HRV;
		output_map[1128] = &cf->softstemc_transfer_to_HRV;
		output_map[1129] = &cf->gresp_storage_to_HRV;
		output_map[1130] = &cf->gresp_transfer_to_HRV;
		output_map[1131] = &cf->HRV_to_CTDBc_leaf;
		output_map[1132] = &cf->HRV_to_CTDBc_fruit;
		output_map[1133] = &cf->HRV_to_CTDBc_softstem;
		output_map[1134] = &cf->HRV_to_CTDBc_transfer;
		output_map[1135] = &cf->STDBc_leaf_to_HRV;
		output_map[1136] = &cf->STDBc_fruit_to_HRV;
		output_map[1137] = &cf->STDBc_softstem_to_HRV;
		output_map[1138] = &cf->STDBc_transfer_to_HRV;
		output_map[1139] = &cf->leafc_to_PLG;
		output_map[1140] = &cf->leafc_storage_to_PLG;
		output_map[1141] = &cf->leafc_transfer_to_PLG;
		output_map[1142] = &cf->frootc_to_PLG;
		output_map[1143] = &cf->frootc_storage_to_PLG;
		output_map[1144] = &cf->frootc_transfer_to_PLG;
		output_map[1145] = &cf->fruitc_to_PLG;
		output_map[1146] = &cf->fruitc_storage_to_PLG;
		output_map[1147] = &cf->fruitc_transfer_to_PLG;
		output_map[1148] = &cf->softstemc_to_PLG;
		output_map[1149] = &cf->softstemc_storage_to_PLG;
		output_map[1150] = &cf->softstemc_transfer_to_PLG;
		output_map[1151] = &cf->gresp_storage_to_PLG;
		output_map[1152] = &cf->gresp_transfer_to_PLG;
		output_map[1153] = &cf->STDBc_leaf_to_PLG;
		output_map[1154] = &cf->STDBc_froot_to_PLG;
		output_map[1155] = &cf->STDBc_fruit_to_PLG;
		output_map[1156] = &cf->STDBc_softstem_to_PLG;
		output_map[1157] = &cf->STDBc_transfer_to_PLG;
		output_map[1158] = &cf->CTDBc_leaf_to_PLG;
		output_map[1159] = &cf->CTDBc_fruit_to_PLG;
		output_map[1160] = &cf->CTDBc_softstem_to_PLG;
		output_map[1161] = &cf->leafc_to_GRZ;
		output_map[1162] = &cf->leafc_storage_to_GRZ;
		output_map[1163] = &cf->leafc_transfer_to_GRZ;
		output_map[1164] = &cf->fruitc_to_GRZ;
		output_map[1165] = &cf->fruitc_storage_to_GRZ;
		output_map[1166] = &cf->fruitc_transfer_to_GRZ;
		output_map[1167] = &cf->softstemc_to_GRZ;
		output_map[1168] = &cf->softstemc_storage_to_GRZ;
		output_map[1169] = &cf->softstemc_transfer_to_GRZ;
		output_map[1170] = &cf->gresp_storage_to_GRZ;
		output_map[1171] = &cf->gresp_transfer_to_GRZ;
		output_map[1172] = &cf->STDBc_leaf_to_GRZ;
		output_map[1173] = &cf->STDBc_fruit_to_GRZ;
		output_map[1174] = &cf->STDBc_softstem_to_GRZ;
		output_map[1175] = &cf->STDBc_transfer_to_GRZ;
		output_map[1176] = &cf->GRZ_to_litr1c;
		output_map[1177] = &cf->GRZ_to_litr2c;
		output_map[1178] = &cf->GRZ_to_litr3c;
		output_map[1179] = &cf->GRZ_to_litr4c;
		output_map[1180] = &cf->FRZ_to_litr1c;
		output_map[1181] = &cf->FRZ_to_litr2c;
		output_map[1182] = &cf->FRZ_to_litr3c;
		output_map[1183] = &cf->FRZ_to_litr4c;
		output_map[1184] = &cf->CH4_flux_soil;
		output_map[1185] = &cf->CH4_flux_MANURE;
		output_map[1186] = &cf->CH4_flux_FERMENT;
		output_map[1300] = &ns->leafn;
		output_map[1301] = &ns->leafn_storage;
		output_map[1302] = &ns->leafn_transfer;
		output_map[1303] = &ns->frootn;
		output_map[1304] = &ns->frootn_storage;
		output_map[1305] = &ns->frootn_transfer;
		output_map[1306] = &ns->fruitn;
		output_map[1307] = &ns->fruitn_storage;
		output_map[1308] = &ns->fruitn_transfer;
		output_map[1309] = &ns->softstemn;
		output_map[1310] = &ns->softstemn_storage;
		output_map[1311] = &ns->softstemn_transfer;
		output_map[1312] = &ns->livestemn;
		output_map[1313] = &ns->livestemn_storage;
		output_map[1314] = &ns->livestemn_transfer;
		output_map[1315] = &ns->deadstemn;
		output_map[1316] = &ns->deadstemn_storage;
		output_map[1317] = &ns->deadstemn_transfer;
		output_map[1318] = &ns->livecrootn;
		output_map[1319] = &ns->livecrootn_storage;
		output_map[1320] = &ns->livecrootn_transfer;
		output_map[1321] = &ns->deadcrootn;
		output_map[1322] = &ns->deadcrootn_storage;
		output_map[1323] = &ns->deadcrootn_transfer;
		output_map[1324] = &ns->npool;
		output_map[1325] = &ns->cwdn[0];
		output_map[1326] = &ns->cwdn[1];
		output_map[1327] = &ns->cwdn[2];
		output_map[1328] = &ns->cwdn[3];
		output_map[1329] = &ns->cwdn[4];
		output_map[1330] = &ns->cwdn[5];
		output_map[1331] = &ns->cwdn[6];
		output_map[1332] = &ns->cwdn[7];
		output_map[1333] = &ns->cwdn[8];
		output_map[1334] = &ns->cwdn[9];
		output_map[1335] = &ns->litr1n[0];
		output_map[1336] = &ns->litr1n[1];
		output_map[1337] = &ns->litr1n[2];
		output_map[1338] = &ns->litr1n[3];
		output_map[1339] = &ns->litr1n[4];
		output_map[1340] = &ns->litr1n[5];
		output_map[1341] = &ns->litr1n[6];
		output_map[1342] = &ns->litr1n[7];
		output_map[1343] = &ns->litr1n[8];
		output_map[1344] = &ns->litr1n[9];
		output_map[1345] = &ns->litr2n[0];
		output_map[1346] = &ns->litr2n[1];
		output_map[1347] = &ns->litr2n[2];
		output_map[1348] = &ns->litr2n[3];
		output_map[1349] = &ns->litr2n[4];
		output_map[1350] = &ns->litr2n[5];
		output_map[1351] = &ns->litr2n[6];
		output_map[1352] = &ns->litr2n[7];
		output_map[1353] = &ns->litr2n[8];
		output_map[1354] = &ns->litr2n[9];
		output_map[1355] = &ns->litr3n[0];
		output_map[1356] = &ns->litr3n[1];
		output_map[1357] = &ns->litr3n[2];
		output_map[1358] = &ns->litr3n[3];
		output_map[1359] = &ns->litr3n[4];
		output_map[1360] = &ns->litr3n[5];
		output_map[1361] = &ns->litr3n[6];
		output_map[1362] = &ns->litr3n[7];
		output_map[1363] = &ns->litr3n[8];
		output_map[1364] = &ns->litr3n[9];
		output_map[1365] = &ns->litr4n[0];
		output_map[1366] = &ns->litr4n[1];
		output_map[1367] = &ns->litr4n[2];
		output_map[1368] = &ns->litr4n[3];
		output_map[1369] = &ns->litr4n[4];
		output_map[1370] = &ns->litr4n[5];
		output_map[1371] = &ns->litr4n[6];
		output_map[1372] = &ns->litr4n[7];
		output_map[1373] = &ns->litr4n[8];
		output_map[1374] = &ns->litr4n[9];
		output_map[1375] = &ns->litrN[0];
		output_map[1376] = &ns->litrN[1];
		output_map[1377] = &ns->litrN[2];
		output_map[1378] = &ns->litrN[3];
		output_map[1379] = &ns->litrN[4];
		output_map[1380] = &ns->litrN[5];
		output_map[1381] = &ns->litrN[6];
		output_map[1382] = &ns->litrN[7];
		output_map[1383] = &ns->litrN[8];
		output_map[1384] = &ns->litrN[9];
		output_map[1385] = &ns->litr1n_total;
		output_map[1386] = &ns->litr2n_total;
		output_map[1387] = &ns->litr3n_total;
		output_map[1388] = &ns->litr4n_total;
		output_map[1389] = &ns->cwdn_total;
		output_map[1390] = &ns->STDBn_leaf;
		output_map[1391] = &ns->STDBn_froot;
		output_map[1392] = &ns->STDBn_fruit;
		output_map[1393] = &ns->STDBn_softstem;
		output_map[1394] = &ns->STDBn_transfer;
		output_map[1395] = &ns->STDBn_above;
		output_map[1396] = &ns->STDBn_below;
		output_map[1397] = &ns->CTDBn_leaf;
		output_map[1398] = &ns->CTDBn_froot;
		output_map[1399] = &ns->CTDBn_fruit;
		output_map[1400] = &ns->CTDBn_softstem;
		output_map[1401] = &ns->CTDBn_transfer;
		output_map[1402] = &ns->CTDBn_cstem;
		output_map[1403] = &ns->CTDBn_croot;
		output_map[1404] = &ns->CTDBn_above;
		output_map[1405] = &ns->CTDBn_below;
		output_map[1406] = &ns->soil1n[0];
		output_map[1407] = &ns->soil1n[1];
		output_map[1408] = &ns->soil1n[2];
		output_map[1409] = &ns->soil1n[3];
		output_map[1410] = &ns->soil1n[4];
		output_map[1411] = &ns->soil1n[5];
		output_map[1412] = &ns->soil1n[6];
		output_map[1413] = &ns->soil1n[7];
		output_map[1414] = &ns->soil1n[8];
		output_map[1415] = &ns->soil1n[9];
		output_map[1416] = &ns->soil2n[0];
		output_map[1417] = &ns->soil2n[1];
		output_map[1418] = &ns->soil2n[2];
		output_map[1419] = &ns->soil2n[3];
		output_map[1420] = &ns->soil2n[4];
		output_map[1421] = &ns->soil2n[5];
		output_map[1422] = &ns->soil2n[6];
		output_map[1423] = &ns->soil2n[7];
		output_map[1424] = &ns->soil2n[8];
		output_map[1425] = &ns->soil2n[9];
		output_map[1426] = &ns->soil3n[0];
		output_map[1427] = &ns->soil3n[1];
		output_map[1428] = &ns->soil3n[2];
		output_map[1429] = &ns->soil3n[3];
		output_map[1430] = &ns->soil3n[4];
		output_map[1431] = &ns->soil3n[5];
		output_map[1432] = &ns->soil3n[6];
		output_map[1433] = &ns->soil3n[7];
		output_map[1434] = &ns->soil3n[8];
		output_map[1435] = &ns->soil3n[9];
		output_map[1436] = &ns->soil4n[0];
		output_map[1437] = &ns->soil4n[1];
		output_map[1438] = &ns->soil4n[2];
		output_map[1439] = &ns->soil4n[3];
		output_map[1440] = &ns->soil4n[4];
		output_map[1441] = &ns->soil4n[5];
		output_map[1442] = &ns->soil4n[6];
		output_map[1443] = &ns->soil4n[7];
		output_map[1444] = &ns->soil4n[8];
		output_map[1445] = &ns->soil4n[9];
		output_map[1446] = &ns->soilN[0];
		output_map[1447] = &ns->soilN[1];
		output_map[1448] = &ns->soilN[2];
		output_map[1449] = &ns->soilN[3];
		output_map[1450] = &ns->soilN[4];
		output_map[1451] = &ns->soilN[5];
		output_map[1452] = &ns->soilN[6];
		output_map[1453] = &ns->soilN[7];
		output_map[1454] = &ns->soilN[8];
		output_map[1455] = &ns->soilN[9];
		output_map[1456] = &ns->soil1_DON[0];
		output_map[1457] = &ns->soil1_DON[1];
		output_map[1458] = &ns->soil1_DON[2];
		output_map[1459] = &ns->soil1_DON[3];
		output_map[1460] = &ns->soil1_DON[4];
		output_map[1461] = &ns->soil1_DON[5];
		output_map[1462] = &ns->soil1_DON[6];
		output_map[1463] = &ns->soil1_DON[7];
		output_map[1464] = &ns->soil1_DON[8];
		output_map[1465] = &ns->soil1_DON[9];
		output_map[1466] = &ns->soil2_DON[0];
		output_map[1467] = &ns->soil2_DON[1];
		output_map[1468] = &ns->soil2_DON[2];
		output_map[1469] = &ns->soil2_DON[3];
		output_map[1470] = &ns->soil2_DON[4];
		output_map[1471] = &ns->soil2_DON[5];
		output_map[1472] = &ns->soil2_DON[6];
		output_map[1473] = &ns->soil2_DON[7];
		output_map[1474] = &ns->soil2_DON[8];
		output_map[1475] = &ns->soil2_DON[9];
		output_map[1476] = &ns->soil3_DON[0];
		output_map[1477] = &ns->soil3_DON[1];
		output_map[1478] = &ns->soil3_DON[2];
		output_map[1479] = &ns->soil3_DON[3];
		output_map[1480] = &ns->soil3_DON[4];
		output_map[1481] = &ns->soil3_DON[5];
		output_map[1482] = &ns->soil3_DON[6];
		output_map[1483] = &ns->soil3_DON[7];
		output_map[1484] = &ns->soil3_DON[8];
		output_map[1485] = &ns->soil3_DON[9];
		output_map[1486] = &ns->soil4_DON[0];
		output_map[1487] = &ns->soil4_DON[1];
		output_map[1488] = &ns->soil4_DON[2];
		output_map[1489] = &ns->soil4_DON[3];
		output_map[1490] = &ns->soil4_DON[4];
		output_map[1491] = &ns->soil4_DON[5];
		output_map[1492] = &ns->soil4_DON[6];
		output_map[1493] = &ns->soil4_DON[7];
		output_map[1494] = &ns->soil4_DON[8];
		output_map[1495] = &ns->soil4_DON[9];
		output_map[1496] = &ns->soil_DON[0];
		output_map[1497] = &ns->soil_DON[1];
		output_map[1498] = &ns->soil_DON[2];
		output_map[1499] = &ns->soil_DON[3];
		output_map[1500] = &ns->soil_DON[4];
		output_map[1501] = &ns->soil_DON[5];
		output_map[1502] = &ns->soil_DON[6];
		output_map[1503] = &ns->soil_DON[7];
		output_map[1504] = &ns->soil_DON[8];
		output_map[1505] = &ns->soil_DON[9];
		output_map[1506] = &ns->soil1n_total;
		output_map[1507] = &ns->soil2n_total;
		output_map[1508] = &ns->soil3n_total;
		output_map[1509] = &ns->soil4n_total;
		output_map[1510] = &ns->retransn;
		output_map[1511] = &ns->sminNH4[0];
		output_map[1512] = &ns->sminNH4[1];
		output_map[1513] = &ns->sminNH4[2];
		output_map[1514] = &ns->sminNH4[3];
		output_map[1515] = &ns->sminNH4[4];
		output_map[1516] = &ns->sminNH4[5];
		output_map[1517] = &ns->sminNH4[6];
		output_map[1518] = &ns->sminNH4[7];
		output_map[1519] = &ns->sminNH4[8];
		output_map[1520] = &ns->sminNH4[9];
		output_map[1521] = &ns->sminNO3[0];
		output_map[1522] = &ns->sminNO3[1];
		output_map[1523] = &ns->sminNO3[2];
		output_map[1524] = &ns->sminNO3[3];
		output_map[1525] = &ns->sminNO3[4];
		output_map[1526] = &ns->sminNO3[5];
		output_map[1527] = &ns->sminNO3[6];
		output_map[1528] = &ns->sminNO3[7];
		output_map[1529] = &ns->sminNO3[8];
		output_map[1530] = &ns->sminNO3[9];
		output_map[1531] = &ns->sminNH4_total;
		output_map[1532] = &ns->sminNO3_total;
		output_map[1533] = &ns->nfix_src;
		output_map[1534] = &ns->ndep_src;
		output_map[1535] = &ns->nleached_snk;
		output_map[1536] = &ns->nvol_snk;
		output_map[1537] = &ns->fire_snk;
		output_map[1538] = &ns->ndiffused_snk;
		output_map[1539] = &ns->SNSCsnk;
		output_map[1540] = &ns->FRZsrc;
		output_map[1541] = &ns->PLTsrc;
		output_map[1542] = &ns->THN_transportN;
		output_map[1543] = &ns->HRV_transportN;
		output_map[1544] = &ns->MOW_transportN;
		output_map[1545] = &ns->GRZsnk;
		output_map[1546] = &ns->GRZsrc;
		output_map[1547] = &ns->BNDRYsrc;
		output_map[1548] = &ns->SPINUPsrc;
		output_map[1549] = &ns->sum_ndemand;
		output_map[1550] = &ns->balanceERR;
		output_map[1551] = &ns->in;
		output_map[1552] = &ns->out;
		output_map[1553] = &ns->store;
		output_map[1700] = &nf->m_leafn_to_litr1n;
		output_map[1701] = &nf->m_leafn_to_litr2n;
		output_map[1702] = &nf->m_leafn_to_litr3n;
		output_map[1703] = &nf->m_leafn_to_litr4n;
		output_map[1704] = &nf->m_frootn_to_litr1n;
		output_map[1705] = &nf->m_frootn_to_litr2n;
		output_map[1706] = &nf->m_frootn_to_litr3n;
		output_map[1707] = &nf->m_frootn_to_litr4n;
		output_map[1708] = &nf->m_fruitn_to_litr1n;
		output_map[1709] = &nf->m_fruitn_to_litr2n;
		output_map[1710] = &nf->m_fruitn_to_litr3n;
		output_map[1711] = &nf->m_fruitn_to_litr4n;
		output_map[1712] = &nf->m_softstemn_to_litr1n;
		output_map[1713] = &nf->m_softstemn_to_litr2n;
		output_map[1714] = &nf->m_softstemn_to_litr3n;
		output_map[1715] = &nf->m_softstemn_to_litr4n;
		output_map[1716] = &nf->m_leafn_storage_to_litr1n;
		output_map[1717] = &nf->m_frootn_storage_to_litr1n;
		output_map[1718] = &nf->m_fruitn_storage_to_litr1n;
		output_map[1719] = &nf->m_fruitn_transfer_to_litr1n;
		output_map[1720] = &nf->m_softstemn_storage_to_litr1n;
		output_map[1721] = &nf->m_softstemn_transfer_to_litr1n;
		output_map[1722] = &nf->m_livestemn_storage_to_litr1n;
		output_map[1723] = &nf->m_deadstemn_storage_to_litr1n;
		output_map[1724] = &nf->m_livecrootn_storage_to_litr1n;
		output_map[1725] = &nf->m_deadcrootn_storage_to_litr1n;
		output_map[1726] = &nf->m_leafn_transfer_to_litr1n;
		output_map[1727] = &nf->m_frootn_transfer_to_litr1n;
		output_map[1728] = &nf->m_livestemn_transfer_to_litr1n;
		output_map[1729] = &nf->m_deadstemn_transfer_to_litr1n;
		output_map[1730] = &nf->m_livecrootn_transfer_to_litr1n;
		output_map[1731] = &nf->m_deadcrootn_transfer_to_litr1n;
		output_map[1732] = &nf->m_livestemn_to_litr1n;
		output_map[1733] = &nf->m_livestemn_to_cwdn;
		output_map[1734] = &nf->m_deadstemn_to_cwdn;
		output_map[1735] = &nf->m_livecrootn_to_litr1n;
		output_map[1736] = &nf->m_livecrootn_to_cwdn;
		output_map[1737] = &nf->m_deadcrootn_to_cwdn;
		output_map[1738] = &nf->m_retransn_to_litr1n;
		output_map[1739] = &nf->m_vegn_to_SNSC;
		output_map[1740] = &nf->m_leafn_to_SNSC;
		output_map[1741] = &nf->m_leafn_to_SNSCgenprog;
		output_map[1742] = &nf->m_frootn_to_SNSC;
		output_map[1743] = &nf->m_leafn_storage_to_SNSC;
		output_map[1744] = &nf->m_frootn_storage_to_SNSC;
		output_map[1745] = &nf->m_leafn_transfer_to_SNSC;
		output_map[1746] = &nf->m_frootn_transfer_to_SNSC;
		output_map[1747] = &nf->m_fruitn_to_SNSC;
		output_map[1748] = &nf->m_fruitn_storage_to_SNSC;
		output_map[1749] = &nf->m_fruitn_transfer_to_SNSC;
		output_map[1750] = &nf->m_softstemn_to_SNSC;
		output_map[1751] = &nf->m_softstemn_storage_to_SNSC;
		output_map[1752] = &nf->m_softstemn_transfer_to_SNSC;
		output_map[1753] = &nf->m_retransn_to_SNSC;
		output_map[1754] = &nf->HRV_leafn_storage_to_SNSC;
		output_map[1755] = &nf->HRV_leafn_transfer_to_SNSC;
		output_map[1756] = &nf->HRV_fruitn_storage_to_SNSC;
		output_map[1757] = &nf->HRV_fruitn_transfer_to_SNSC;
		output_map[1758] = &nf->HRV_frootn_to_SNSC;
		output_map[1759] = &nf->HRV_softstemn_to_SNSC;
		output_map[1760] = &nf->HRV_frootn_storage_to_SNSC;
		output_map[1761] = &nf->HRV_frootn_transfer_to_SNSC;
		output_map[1762] = &nf->HRV_softstemn_storage_to_SNSC;
		output_map[1763] = &nf->HRV_softstemn_transfer_to_SNSC;
		output_map[1764] = &nf->HRV_retransn_to_SNSC;
		output_map[1765] = &nf->fruitn_to_flowHS;
		output_map[1766] = &nf->STDBn_leaf_to_litr;
		output_map[1767] = &nf->STDBn_froot_to_litr;
		output_map[1768] = &nf->STDBn_fruit_to_litr;
		output_map[1769] = &nf->STDBn_softstem_to_litr;
		output_map[1770] = &nf->STDBn_transfer_to_litr;
		output_map[1771] = &nf->STDBn_to_litr;
		output_map[1772] = &nf->CTDBn_leaf_to_litr;
		output_map[1773] = &nf->CTDBn_froot_to_litr;
		output_map[1774] = &nf->CTDBn_fruit_to_litr;
		output_map[1775] = &nf->CTDBn_softstem_to_litr;
		output_map[1776] = &nf->CTDBn_transfer_to_litr;
		output_map[1777] = &nf->CTDBn_cstem_to_cwd;
		output_map[1778] = &nf->CTDBn_croot_to_cwd;
		output_map[1779] = &nf->CTDBn_to_litr;
		output_map[1780] = &nf->m_leafn_to_fire;
		output_map[1781] = &nf->m_frootn_to_fire;
		output_map[1782] = &nf->m_fruitn_to_fire;
		output_map[1783] = &nf->m_softstemn_to_fire;
		output_map[1784] = &nf->m_STDBn_to_fire;
		output_map[1785] = &nf->m_CTDBn_to_fire;
		output_map[1786] = &nf->m_leafn_storage_to_fire;
		output_map[1787] = &nf->m_frootn_storage_to_fire;
		output_map[1788] = &nf->m_fruitn_storage_to_fire;
		output_map[1789] = &nf->m_fruitn_transfer_to_fire;
		output_map[1790] = &nf->m_softstemn_storage_to_fire;
		output_map[1791] = &nf->m_softstemn_transfer_to_fire;
		output_map[1792] = &nf->m_livestemn_storage_to_fire;
		output_map[1793] = &nf->m_deadstemn_storage_to_fire;
		output_map[1794] = &nf->m_livecrootn_storage_to_fire;
		output_map[1795] = &nf->m_deadcrootn_storage_to_fire;
		output_map[1796] = &nf->m_leafn_transfer_to_fire;
		output_map[1797] = &nf->m_frootn_transfer_to_fire;
		output_map[1798] = &nf->m_livestemn_transfer_to_fire;
		output_map[1799] = &nf->m_deadstemn_transfer_to_fire;
		output_map[1800] = &nf->m_livecrootn_transfer_to_fire;
		output_map[1801] = &nf->m_deadcrootn_transfer_to_fire;
		output_map[1802] = &nf->m_livestemn_to_fire;
		output_map[1803] = &nf->m_deadstemn_to_fire;
		output_map[1804] = &nf->m_livecrootn_to_fire;
		output_map[1805] = &nf->m_deadcrootn_to_fire;
		output_map[1806] = &nf->m_retransn_to_fire;
		output_map[1807] = &nf->m_litr1n_to_fire;
		output_map[1808] = &nf->m_litr2n_to_fire;
		output_map[1809] = &nf->m_litr3n_to_fire;
		output_map[1810] = &nf->m_litr4n_to_fire;
		output_map[1811] = &nf->m_cwdn_to_fire;
		output_map[1812] = &nf->leafn_transfer_to_leafn;
		output_map[1813] = &nf->frootn_transfer_to_frootn;
		output_map[1814] = &nf->fruitn_transfer_to_fruitn;
		output_map[1815] = &nf->softstemn_transfer_to_softstemn;
		output_map[1816] = &nf->livestemn_transfer_to_livestemn;
		output_map[1817] = &nf->deadstemn_transfer_to_deadstemn;
		output_map[1818] = &nf->livecrootn_transfer_to_livecrootn;
		output_map[1819] = &nf->deadcrootn_transfer_to_deadcrootn;
		output_map[1820] = &nf->leafn_to_litr1n;
		output_map[1821] = &nf->leafn_to_litr2n;
		output_map[1822] = &nf->leafn_to_litr3n;
		output_map[1823] = &nf->leafn_to_litr4n;
		output_map[1824] = &nf->leafn_to_retransn;
		output_map[1825] = &nf->frootn_to_litr1n;
		output_map[1826] = &nf->frootn_to_litr2n;
		output_map[1827] = &nf->frootn_to_litr3n;
		output_map[1828] = &nf->frootn_to_litr4n;
		output_map[1829] = &nf->fruitn_to_litr1n;
		output_map[1830] = &nf->fruitn_to_litr2n;
		output_map[1831] = &nf->fruitn_to_litr3n;
		output_map[1832] = &nf->fruitn_to_litr4n;
		output_map[1833] = &nf->softstemn_to_litr1n;
		output_map[1834] = &nf->softstemn_to_litr2n;
		output_map[1835] = &nf->softstemn_to_litr3n;
		output_map[1836] = &nf->softstemn_to_litr4n;
		output_map[1837] = &nf->ndep_to_sminn;
		output_map[1838] = &nf->nfix_to_sminn;
		output_map[1839] = &nf->cwdn_to_litr2n[0];
		output_map[1840] = &nf->cwdn_to_litr2n[1];
		output_map[1841] = &nf->cwdn_to_litr2n[2];
		output_map[1842] = &nf->cwdn_to_litr2n[3];
		output_map[1843] = &nf->cwdn_to_litr2n[4];
		output_map[1844] = &nf->cwdn_to_litr2n[5];
		output_map[1845] = &nf->cwdn_to_litr2n[6];
		output_map[1846] = &nf->cwdn_to_litr2n[7];
		output_map[1847] = &nf->cwdn_to_litr2n[8];
		output_map[1848] = &nf->cwdn_to_litr2n[9];
		output_map[1849] = &nf->cwdn_to_litr3n[0];
		output_map[1850] = &nf->cwdn_to_litr3n[1];
		output_map[1851] = &nf->cwdn_to_litr3n[2];
		output_map[1852] = &nf->cwdn_to_litr3n[3];
		output_map[1853] = &nf->cwdn_to_litr3n[4];
		output_map[1854] = &nf->cwdn_to_litr3n[5];
		output_map[1855] = &nf->cwdn_to_litr3n[6];
		output_map[1856] = &nf->cwdn_to_litr3n[7];
		output_map[1857] = &nf->cwdn_to_litr3n[8];
		output_map[1858] = &nf->cwdn_to_litr3n[9];
		output_map[1859] = &nf->cwdn_to_litr4n[0];
		output_map[1860] = &nf->cwdn_to_litr4n[1];
		output_map[1861] = &nf->cwdn_to_litr4n[2];
		output_map[1862] = &nf->cwdn_to_litr4n[3];
		output_map[1863] = &nf->cwdn_to_litr4n[4];
		output_map[1864] = &nf->cwdn_to_litr4n[5];
		output_map[1865] = &nf->cwdn_to_litr4n[6];
		output_map[1866] = &nf->cwdn_to_litr4n[7];
		output_map[1867] = &nf->cwdn_to_litr4n[8];
		output_map[1868] = &nf->cwdn_to_litr4n[9];
		output_map[1869] = &nf->litr1n_to_soil1n[0];
		output_map[1870] = &nf->litr1n_to_soil1n[1];
		output_map[1871] = &nf->litr1n_to_soil1n[2];
		output_map[1872] = &nf->litr1n_to_soil1n[3];
		output_map[1873] = &nf->litr1n_to_soil1n[4];
		output_map[1874] = &nf->litr1n_to_soil1n[5];
		output_map[1875] = &nf->litr1n_to_soil1n[6];
		output_map[1876] = &nf->litr1n_to_soil1n[7];
		output_map[1877] = &nf->litr1n_to_soil1n[8];
		output_map[1878] = &nf->litr1n_to_soil1n[9];
		output_map[1879] = &nf->litr2n_to_soil2n[0];
		output_map[1880] = &nf->litr2n_to_soil2n[1];
		output_map[1881] = &nf->litr2n_to_soil2n[2];
		output_map[1882] = &nf->litr2n_to_soil2n[3];
		output_map[1883] = &nf->litr2n_to_soil2n[4];
		output_map[1884] = &nf->litr2n_to_soil2n[5];
		output_map[1885] = &nf->litr2n_to_soil2n[6];
		output_map[1886] = &nf->litr2n_to_soil2n[7];
		output_map[1887] = &nf->litr2n_to_soil2n[8];
		output_map[1888] = &nf->litr2n_to_soil2n[9];
		output_map[1889] = &nf->litr3n_to_litr2n[0];
		output_map[1890] = &nf->litr3n_to_litr2n[1];
		output_map[1891] = &nf->litr3n_to_litr2n[2];
		output_map[1892] = &nf->litr3n_to_litr2n[3];
		output_map[1893] = &nf->litr3n_to_litr2n[4];
		output_map[1894] = &nf->litr3n_to_litr2n[5];
		output_map[1895] = &nf->litr3n_to_litr2n[6];
		output_map[1896] = &nf->litr3n_to_litr2n[7];
		output_map[1897] = &nf->litr3n_to_litr2n[8];
		output_map[1898] = &nf->litr3n_to_litr2n[9];
		output_map[1899] = &nf->litr4n_to_soil3n[0];
		output_map[1900] = &nf->litr4n_to_soil3n[1];
		output_map[1901] = &nf->litr4n_to_soil3n[2];
		output_map[1902] = &nf->litr4n_to_soil3n[3];
		output_map[1903] = &nf->litr4n_to_soil3n[4];
		output_map[1904] = &nf->litr4n_to_soil3n[5];
		output_map[1905] = &nf->litr4n_to_soil3n[6];
		output_map[1906] = &nf->litr4n_to_soil3n[7];
		output_map[1907] = &nf->litr4n_to_soil3n[8];
		output_map[1908] = &nf->litr4n_to_soil3n[9];
		output_map[1909] = &nf->soil1n_to_soil2n[0];
		output_map[1910] = &nf->soil1n_to_soil2n[1];
		output_map[1911] = &nf->soil1n_to_soil2n[2];
		output_map[1912] = &nf->soil1n_to_soil2n[3];
		output_map[1913] = &nf->soil1n_to_soil2n[4];
		output_map[1914] = &nf->soil1n_to_soil2n[5];
		output_map[1915] = &nf->soil1n_to_soil2n[6];
		output_map[1916] = &nf->soil1n_to_soil2n[7];
		output_map[1917] = &nf->soil1n_to_soil2n[8];
		output_map[1918] = &nf->soil1n_to_soil2n[9];
		output_map[1919] = &nf->soil2n_to_soil3n[0];
		output_map[1920] = &nf->soil2n_to_soil3n[1];
		output_map[1921] = &nf->soil2n_to_soil3n[2];
		output_map[1922] = &nf->soil2n_to_soil3n[3];
		output_map[1923] = &nf->soil2n_to_soil3n[4];
		output_map[1924] = &nf->soil2n_to_soil3n[5];
		output_map[1925] = &nf->soil2n_to_soil3n[6];
		output_map[1926] = &nf->soil2n_to_soil3n[7];
		output_map[1927] = &nf->soil2n_to_soil3n[8];
		output_map[1928] = &nf->soil2n_to_soil3n[9];
		output_map[1929] = &nf->soil3n_to_soil4n[0];
		output_map[1930] = &nf->soil3n_to_soil4n[1];
		output_map[1931] = &nf->soil3n_to_soil4n[2];
		output_map[1932] = &nf->soil3n_to_soil4n[3];
		output_map[1933] = &nf->soil3n_to_soil4n[4];
		output_map[1934] = &nf->soil3n_to_soil4n[5];
		output_map[1935] = &nf->soil3n_to_soil4n[6];
		output_map[1936] = &nf->soil3n_to_soil4n[7];
		output_map[1937] = &nf->soil3n_to_soil4n[8];
		output_map[1938] = &nf->soil3n_to_soil4n[9];
		output_map[1939] = &nf->soil4n_to_sminNH4[0];
		output_map[1940] = &nf->soil4n_to_sminNH4[1];
		output_map[1941] = &nf->soil4n_to_sminNH4[2];
		output_map[1942] = &nf->soil4n_to_sminNH4[3];
		output_map[1943] = &nf->soil4n_to_sminNH4[4];
		output_map[1944] = &nf->soil4n_to_sminNH4[5];
		output_map[1945] = &nf->soil4n_to_sminNH4[6];
		output_map[1946] = &nf->soil4n_to_sminNH4[7];
		output_map[1947] = &nf->soil4n_to_sminNH4[8];
		output_map[1948] = &nf->soil4n_to_sminNH4[9];
		output_map[1949] = &nf->soil4n_to_sminNH4_total;
		output_map[1950] = &nf->sminn_to_soil_SUM[0];
		output_map[1951] = &nf->sminn_to_soil_SUM[1];
		output_map[1952] = &nf->sminn_to_soil_SUM[2];
		output_map[1953] = &nf->sminn_to_soil_SUM[3];
		output_map[1954] = &nf->sminn_to_soil_SUM[4];
		output_map[1955] = &nf->sminn_to_soil_SUM[5];
		output_map[1956] = &nf->sminn_to_soil_SUM[6];
		output_map[1957] = &nf->sminn_to_soil_SUM[7];
		output_map[1958] = &nf->sminn_to_soil_SUM[8];
		output_map[1959] = &nf->sminn_to_soil_SUM[9];
		output_map[1960] = &nf->sminNH4_to_soil_SUM[0];
		output_map[1961] = &nf->sminNH4_to_soil_SUM[1];
		output_map[1962] = &nf->sminNH4_to_soil_SUM[2];
		output_map[1963] = &nf->sminNH4_to_soil_SUM[3];
		output_map[1964] = &nf->sminNH4_to_soil_SUM[4];
		output_map[1965] = &nf->sminNH4_to_soil_SUM[5];
		output_map[1966] = &nf->sminNH4_to_soil_SUM[6];
		output_map[1967] = &nf->sminNH4_to_soil_SUM[7];
		output_map[1968] = &nf->sminNH4_to_soil_SUM[8];
		output_map[1969] = &nf->sminNH4_to_soil_SUM[9];
		output_map[1970] = &nf->sminNO3_to_soil_SUM[0];
		output_map[1971] = &nf->sminNO3_to_soil_SUM[1];
		output_map[1972] = &nf->sminNO3_to_soil_SUM[2];
		output_map[1973] = &nf->sminNO3_to_soil_SUM[3];
		output_map[1974] = &nf->sminNO3_to_soil_SUM[4];
		output_map[1975] = &nf->sminNO3_to_soil_SUM[5];
		output_map[1976] = &nf->sminNO3_to_soil_SUM[6];
		output_map[1977] = &nf->sminNO3_to_soil_SUM[7];
		output_map[1978] = &nf->sminNO3_to_soil_SUM[8];
		output_map[1979] = &nf->sminNO3_to_soil_SUM[9];
		output_map[1980] = &nf->sminn_to_soil1n_l1[0];
		output_map[1981] = &nf->sminn_to_soil1n_l1[1];
		output_map[1982] = &nf->sminn_to_soil1n_l1[2];
		output_map[1983] = &nf->sminn_to_soil1n_l1[3];
		output_map[1984] = &nf->sminn_to_soil1n_l1[4];
		output_map[1985] = &nf->sminn_to_soil1n_l1[5];
		output_map[1986] = &nf->sminn_to_soil1n_l1[6];
		output_map[1987] = &nf->sminn_to_soil1n_l1[7];
		output_map[1988] = &nf->sminn_to_soil1n_l1[8];
		output_map[1989] = &nf->sminn_to_soil1n_l1[9];
		output_map[1990] = &nf->sminn_to_soil2n_l2[0];
		output_map[1991] = &nf->sminn_to_soil2n_l2[1];
		output_map[1992] = &nf->sminn_to_soil2n_l2[2];
		output_map[1993] = &nf->sminn_to_soil2n_l2[3];
		output_map[1994] = &nf->sminn_to_soil2n_l2[4];
		output_map[1995] = &nf->sminn_to_soil2n_l2[5];
		output_map[1996] = &nf->sminn_to_soil2n_l2[6];
		output_map[1997] = &nf->sminn_to_soil2n_l2[7];
		output_map[1998] = &nf->sminn_to_soil2n_l2[8];
		output_map[1999] = &nf->sminn_to_soil2n_l2[9];
		output_map[2000] = &nf->sminn_to_soil3n_l4[0];
		output_map[2001] = &nf->sminn_to_soil3n_l4[1];
		output_map[2002] = &nf->sminn_to_soil3n_l4[2];
		output_map[2003] = &nf->sminn_to_soil3n_l4[3];
		output_map[2004] = &nf->sminn_to_soil3n_l4[4];
		output_map[2005] = &nf->sminn_to_soil3n_l4[5];
		output_map[2006] = &nf->sminn_to_soil3n_l4[6];
		output_map[2007] = &nf->sminn_to_soil3n_l4[7];
		output_map[2008] = &nf->sminn_to_soil3n_l4[8];
		output_map[2009] = &nf->sminn_to_soil3n_l4[9];
		output_map[2010] = &nf->sminn_to_soil2n_s1[0];
		output_map[2011] = &nf->sminn_to_soil2n_s1[1];
		output_map[2012] = &nf->sminn_to_soil2n_s1[2];
		output_map[2013] = &nf->sminn_to_soil2n_s1[3];
		output_map[2014] = &nf->sminn_to_soil2n_s1[4];
		output_map[2015] = &nf->sminn_to_soil2n_s1[5];
		output_map[2016] = &nf->sminn_to_soil2n_s1[6];
		output_map[2017] = &nf->sminn_to_soil2n_s1[7];
		output_map[2018] = &nf->sminn_to_soil2n_s1[8];
		output_map[2019] = &nf->sminn_to_soil2n_s1[9];
		output_map[2020] = &nf->sminn_to_soil3n_s2[0];
		output_map[2021] = &nf->sminn_to_soil3n_s2[1];
		output_map[2022] = &nf->sminn_to_soil3n_s2[2];
		output_map[2023] = &nf->sminn_to_soil3n_s2[3];
		output_map[2024] = &nf->sminn_to_soil3n_s2[4];
		output_map[2025] = &nf->sminn_to_soil3n_s2[5];
		output_map[2026] = &nf->sminn_to_soil3n_s2[6];
		output_map[2027] = &nf->sminn_to_soil3n_s2[7];
		output_map[2028] = &nf->sminn_to_soil3n_s2[8];
		output_map[2029] = &nf->sminn_to_soil3n_s2[9];
		output_map[2030] = &nf->sminn_to_soil4n_s3[0];
		output_map[2031] = &nf->sminn_to_soil4n_s3[1];
		output_map[2032] = &nf->sminn_to_soil4n_s3[2];
		output_map[2033] = &nf->sminn_to_soil4n_s3[3];
		output_map[2034] = &nf->sminn_to_soil4n_s3[4];
		output_map[2035] = &nf->sminn_to_soil4n_s3[5];
		output_map[2036] = &nf->sminn_to_soil4n_s3[6];
		output_map[2037] = &nf->sminn_to_soil4n_s3[7];
		output_map[2038] = &nf->sminn_to_soil4n_s3[8];
		output_map[2039] = &nf->sminn_to_soil4n_s3[9];
		output_map[2040] = &nf->sminn_to_soil_SUM_total;
		output_map[2041] = &nf->sminNH4_to_soil_SUM_total;
		output_map[2042] = &nf->sminNO3_to_soil_SUM_total;
		output_map[2043] = &nf->sminNO3_to_denitr[0];
		output_map[2044] = &nf->sminNO3_to_denitr[1];
		output_map[2045] = &nf->sminNO3_to_denitr[2];
		output_map[2046] = &nf->sminNO3_to_denitr[3];
		output_map[2047] = &nf->sminNO3_to_denitr[4];
		output_map[2048] = &nf->sminNO3_to_denitr[5];
		output_map[2049] = &nf->sminNO3_to_denitr[6];
		output_map[2050] = &nf->sminNO3_to_denitr[7];
		output_map[2051] = &nf->sminNO3_to_denitr[8];
		output_map[2052] = &nf->sminNO3_to_denitr[9];
		output_map[2053] = &nf->sminNH4_to_nitrif[0];
		output_map[2054] = &nf->sminNH4_to_nitrif[1];
		output_map[2055] = &nf->sminNH4_to_nitrif[2];
		output_map[2056] = &nf->sminNH4_to_nitrif[3];
		output_map[2057] = &nf->sminNH4_to_nitrif[4];
		output_map[2058] = &nf->sminNH4_to_nitrif[5];
		output_map[2059] = &nf->sminNH4_to_nitrif[6];
		output_map[2060] = &nf->sminNH4_to_nitrif[7];
		output_map[2061] = &nf->sminNH4_to_nitrif[8];
		output_map[2062] = &nf->sminNH4_to_nitrif[9];
		output_map[2063] = &nf->N2_flux_DENITR[0];
		output_map[2064] = &nf->N2_flux_DENITR[1];
		output_map[2065] = &nf->N2_flux_DENITR[2];
		output_map[2066] = &nf->N2_flux_DENITR[3];
		output_map[2067] = &nf->N2_flux_DENITR[4];
		output_map[2068] = &nf->N2_flux_DENITR[5];
		output_map[2069] = &nf->N2_flux_DENITR[6];
		output_map[2070] = &nf->N2_flux_DENITR[7];
		output_map[2071] = &nf->N2_flux_DENITR[8];
		output_map[2072] = &nf->N2_flux_DENITR[9];
		output_map[2073] = &nf->N2O_flux_NITRIF[0];
		output_map[2074] = &nf->N2O_flux_NITRIF[1];
		output_map[2075] = &nf->N2O_flux_NITRIF[2];
		output_map[2076] = &nf->N2O_flux_NITRIF[3];
		output_map[2077] = &nf->N2O_flux_NITRIF[4];
		output_map[2078] = &nf->N2O_flux_NITRIF[5];
		output_map[2079] = &nf->N2O_flux_NITRIF[6];
		output_map[2080] = &nf->N2O_flux_NITRIF[7];
		output_map[2081] = &nf->N2O_flux_NITRIF[8];
		output_map[2082] = &nf->N2O_flux_NITRIF[9];
		output_map[2083] = &nf->N2O_flux_DENITR[0];
		output_map[2084] = &nf->N2O_flux_DENITR[1];
		output_map[2085] = &nf->N2O_flux_DENITR[2];
		output_map[2086] = &nf->N2O_flux_DENITR[3];
		output_map[2087] = &nf->N2O_flux_DENITR[4];
		output_map[2088] = &nf->N2O_flux_DENITR[5];
		output_map[2089] = &nf->N2O_flux_DENITR[6];
		output_map[2090] = &nf->N2O_flux_DENITR[7];
		output_map[2091] = &nf->N2O_flux_DENITR[8];
		output_map[2092] = &nf->N2O_flux_DENITR[9];
		output_map[2093] = &nf->sminNO3_to_denitr_total;
		output_map[2094] = &nf->sminNH4_to_nitrif_total;
		output_map[2095] = &nf->N2_flux_DENITR_total;
		output_map[2096] = &nf->N2O_flux_NITRIF_total;
		output_map[2097] = &nf->N2O_flux_DENITR_total;
		output_map[2098] = &nf->sminNH4_to_npool[0];
		output_map[2099] = &nf->sminNH4_to_npool[1];
		output_map[2100] = &nf->sminNH4_to_npool[2];
		output_map[2101] = &nf->sminNH4_to_npool[3];
		output_map[2102] = &nf->sminNH4_to_npool[4];
		output_map[2103] = &nf->sminNH4_to_npool[5];
		output_map[2104] = &nf->sminNH4_to_npool[6];
		output_map[2105] = &nf->sminNH4_to_npool[7];
		output_map[2106] = &nf->sminNH4_to_npool[8];
		output_map[2107] = &nf->sminNH4_to_npool[9];
		output_map[2108] = &nf->sminNO3_to_npool[0];
		output_map[2109] = &nf->sminNO3_to_npool[1];
		output_map[2110] = &nf->sminNO3_to_npool[2];
		output_map[2111] = &nf->sminNO3_to_npool[3];
		output_map[2112] = &nf->sminNO3_to_npool[4];
		output_map[2113] = &nf->sminNO3_to_npool[5];
		output_map[2114] = &nf->sminNO3_to_npool[6];
		output_map[2115] = &nf->sminNO3_to_npool[7];
		output_map[2116] = &nf->sminNO3_to_npool[8];
		output_map[2117] = &nf->sminNO3_to_npool[9];
		output_map[2118] = &nf->sminNH4_to_npool_total;
		output_map[2119] = &nf->sminNO3_to_npool_total;
		output_map[2120] = &nf->sminn_to_npool;
		output_map[2121] = &nf->sminNH4_leached[0];
		output_map[2122] = &nf->sminNH4_leached[1];
		output_map[2123] = &nf->sminNH4_leached[2];
		output_map[2124] = &nf->sminNH4_leached[3];
		output_map[2125] = &nf->sminNH4_leached[4];
		output_map[2126] = &nf->sminNH4_leached[5];
		output_map[2127] = &nf->sminNH4_leached[6];
		output_map[2128] = &nf->sminNH4_leached[7];
		output_map[2129] = &nf->sminNH4_leached[8];
		output_map[2130] = &nf->sminNH4_leached[9];
		output_map[2131] = &nf->sminNH4_diffused[0];
		output_map[2132] = &nf->sminNH4_diffused[1];
		output_map[2133] = &nf->sminNH4_diffused[2];
		output_map[2134] = &nf->sminNH4_diffused[3];
		output_map[2135] = &nf->sminNH4_diffused[4];
		output_map[2136] = &nf->sminNH4_diffused[5];
		output_map[2137] = &nf->sminNH4_diffused[6];
		output_map[2138] = &nf->sminNH4_diffused[7];
		output_map[2139] = &nf->sminNH4_diffused[8];
		output_map[2140] = &nf->sminNH4_diffused[9];
		output_map[2141] = &nf->sminNO3_leached[0];
		output_map[2142] = &nf->sminNO3_leached[1];
		output_map[2143] = &nf->sminNO3_leached[2];
		output_map[2144] = &nf->sminNO3_leached[3];
		output_map[2145] = &nf->sminNO3_leached[4];
		output_map[2146] = &nf->sminNO3_leached[5];
		output_map[2147] = &nf->sminNO3_leached[6];
		output_map[2148] = &nf->sminNO3_leached[7];
		output_map[2149] = &nf->sminNO3_leached[8];
		output_map[2150] = &nf->sminNO3_leached[9];
		output_map[2151] = &nf->sminNO3_diffused[0];
		output_map[2152] = &nf->sminNO3_diffused[1];
		output_map[2153] = &nf->sminNO3_diffused[2];
		output_map[2154] = &nf->sminNO3_diffused[3];
		output_map[2155] = &nf->sminNO3_diffused[4];
		output_map[2156] = &nf->sminNO3_diffused[5];
		output_map[2157] = &nf->sminNO3_diffused[6];
		output_map[2158] = &nf->sminNO3_diffused[7];
		output_map[2159] = &nf->sminNO3_diffused[8];
		output_map[2160] = &nf->sminNO3_diffused[9];
		output_map[2161] = &nf->sminN_rootzone_leach;
		output_map[2162] = &nf->soil1_DON_leached[0];
		output_map[2163] = &nf->soil1_DON_leached[1];
		output_map[2164] = &nf->soil1_DON_leached[2];
		output_map[2165] = &nf->soil1_DON_leached[3];
		output_map[2166] = &nf->soil1_DON_leached[4];
		output_map[2167] = &nf->soil1_DON_leached[5];
		output_map[2168] = &nf->soil1_DON_leached[6];
		output_map[2169] = &nf->soil1_DON_leached[7];
		output_map[2170] = &nf->soil1_DON_leached[8];
		output_map[2171] = &nf->soil1_DON_leached[9];
		output_map[2172] = &nf->soil2_DON_leached[0];
		output_map[2173] = &nf->soil2_DON_leached[1];
		output_map[2174] = &nf->soil2_DON_leached[2];
		output_map[2175] = &nf->soil2_DON_leached[3];
		output_map[2176] = &nf->soil2_DON_leached[4];
		output_map[2177] = &nf->soil2_DON_leached[5];
		output_map[2178] = &nf->soil2_DON_leached[6];
		output_map[2179] = &nf->soil2_DON_leached[7];
		output_map[2180] = &nf->soil2_DON_leached[8];
		output_map[2181] = &nf->soil2_DON_leached[9];
		output_map[2182] = &nf->soil3_DON_leached[0];
		output_map[2183] = &nf->soil3_DON_leached[1];
		output_map[2184] = &nf->soil3_DON_leached[2];
		output_map[2185] = &nf->soil3_DON_leached[3];
		output_map[2186] = &nf->soil3_DON_leached[4];
		output_map[2187] = &nf->soil3_DON_leached[5];
		output_map[2188] = &nf->soil3_DON_leached[6];
		output_map[2189] = &nf->soil3_DON_leached[7];
		output_map[2190] = &nf->soil3_DON_leached[8];
		output_map[2191] = &nf->soil3_DON_leached[9];
		output_map[2192] = &nf->soil4_DON_leached[0];
		output_map[2193] = &nf->soil4_DON_leached[1];
		output_map[2194] = &nf->soil4_DON_leached[2];
		output_map[2195] = &nf->soil4_DON_leached[3];
		output_map[2196] = &nf->soil4_DON_leached[4];
		output_map[2197] = &nf->soil4_DON_leached[5];
		output_map[2198] = &nf->soil4_DON_leached[6];
		output_map[2199] = &nf->soil4_DON_leached[7];
		output_map[2200] = &nf->soil4_DON_leached[8];
		output_map[2201] = &nf->soil4_DON_leached[9];
		output_map[2202] = &nf->soil1_DON_diffused[0];
		output_map[2203] = &nf->soil1_DON_diffused[1];
		output_map[2204] = &nf->soil1_DON_diffused[2];
		output_map[2205] = &nf->soil1_DON_diffused[3];
		output_map[2206] = &nf->soil1_DON_diffused[4];
		output_map[2207] = &nf->soil1_DON_diffused[5];
		output_map[2208] = &nf->soil1_DON_diffused[6];
		output_map[2209] = &nf->soil1_DON_diffused[7];
		output_map[2210] = &nf->soil1_DON_diffused[8];
		output_map[2211] = &nf->soil1_DON_diffused[9];
		output_map[2212] = &nf->soil2_DON_diffused[0];
		output_map[2213] = &nf->soil2_DON_diffused[1];
		output_map[2214] = &nf->soil2_DON_diffused[2];
		output_map[2215] = &nf->soil2_DON_diffused[3];
		output_map[2216] = &nf->soil2_DON_diffused[4];
		output_map[2217] = &nf->soil2_DON_diffused[5];
		output_map[2218] = &nf->soil2_DON_diffused[6];
		output_map[2219] = &nf->soil2_DON_diffused[7];
		output_map[2220] = &nf->soil2_DON_diffused[8];
		output_map[2221] = &nf->soil2_DON_diffused[9];
		output_map[2222] = &nf->soil3_DON_diffused[0];
		output_map[2223] = &nf->soil3_DON_diffused[1];
		output_map[2224] = &nf->soil3_DON_diffused[2];
		output_map[2225] = &nf->soil3_DON_diffused[3];
		output_map[2226] = &nf->soil3_DON_diffused[4];
		output_map[2227] = &nf->soil3_DON_diffused[5];
		output_map[2228] = &nf->soil3_DON_diffused[6];
		output_map[2229] = &nf->soil3_DON_diffused[7];
		output_map[2230] = &nf->soil3_DON_diffused[8];
		output_map[2231] = &nf->soil3_DON_diffused[9];
		output_map[2232] = &nf->soil4_DON_diffused[0];
		output_map[2233] = &nf->soil4_DON_diffused[1];
		output_map[2234] = &nf->soil4_DON_diffused[2];
		output_map[2235] = &nf->soil4_DON_diffused[3];
		output_map[2236] = &nf->soil4_DON_diffused[4];
		output_map[2237] = &nf->soil4_DON_diffused[5];
		output_map[2238] = &nf->soil4_DON_diffused[6];
		output_map[2239] = &nf->soil4_DON_diffused[7];
		output_map[2240] = &nf->soil4_DON_diffused[8];
		output_map[2241] = &nf->soil4_DON_diffused[9];
		output_map[2242] = &nf->DON_rootzone_leach;
		output_map[2243] = &nf->retransn_to_npool;
		output_map[2244] = &nf->npool_to_leafn;
		output_map[2245] = &nf->npool_to_leafn_storage;
		output_map[2246] = &nf->npool_to_frootn;
		output_map[2247] = &nf->npool_to_frootn_storage;
		output_map[2248] = &nf->npool_to_fruitn;
		output_map[2249] = &nf->npool_to_fruitn_storage;
		output_map[2250] = &nf->npool_to_softstemn;
		output_map[2251] = &nf->npool_to_softstemn_storage;
		output_map[2252] = &nf->npool_to_livestemn;
		output_map[2253] = &nf->npool_to_livestemn_storage;
		output_map[2254] = &nf->npool_to_deadstemn;
		output_map[2255] = &nf->npool_to_deadstemn_storage;
		output_map[2256] = &nf->npool_to_livecrootn;
		output_map[2257] = &nf->npool_to_livecrootn_storage;
		output_map[2258] = &nf->npool_to_deadcrootn;
		output_map[2259] = &nf->npool_to_deadcrootn_storage;
		output_map[2260] = &nf->leafn_storage_to_maintresp;
		output_map[2261] = &nf->frootn_storage_to_maintresp;
		output_map[2262] = &nf->fruitn_storage_to_maintresp;
		output_map[2263] = &nf->softstemn_storage_to_maintresp;
		output_map[2264] = &nf->livestemn_storage_to_maintresp;
		output_map[2265] = &nf->livecrootn_storage_to_maintresp;
		output_map[2266] = &nf->deadstemn_storage_to_maintresp;
		output_map[2267] = &nf->deadcrootn_storage_to_maintresp;
		output_map[2268] = &nf->leafn_transfer_to_maintresp;
		output_map[2269] = &nf->frootn_transfer_to_maintresp;
		output_map[2270] = &nf->fruitn_transfer_to_maintresp;
		output_map[2271] = &nf->softstemn_transfer_to_maintresp;
		output_map[2272] = &nf->livestemn_transfer_to_maintresp;
		output_map[2273] = &nf->livecrootn_transfer_to_maintresp;
		output_map[2274] = &nf->deadstemn_transfer_to_maintresp;
		output_map[2275] = &nf->deadcrootn_transfer_to_maintresp;
		output_map[2276] = &nf->leafn_to_maintresp;
		output_map[2277] = &nf->frootn_to_maintresp;
		output_map[2278] = &nf->fruitn_to_maintresp;
		output_map[2279] = &nf->softstemn_to_maintresp;
		output_map[2280] = &nf->livestemn_to_maintresp;
		output_map[2281] = &nf->livecrootn_to_maintresp;
		output_map[2282] = &nf->NSN_nw_to_maintresp;
		output_map[2283] = &nf->actN_nw_to_maintresp;
		output_map[2284] = &nf->NSN_w_to_maintresp;
		output_map[2285] = &nf->actN_w_to_maintresp;
		output_map[2286] = &nf->leafn_storage_to_leafn_transfer;
		output_map[2287] = &nf->frootn_storage_to_frootn_transfer;
		output_map[2288] = &nf->livestemn_storage_to_livestemn_transfer;
		output_map[2289] = &nf->deadstemn_storage_to_deadstemn_transfer;
		output_map[2290] = &nf->livecrootn_storage_to_livecrootn_transfer;
		output_map[2291] = &nf->deadcrootn_storage_to_deadcrootn_transfer;
		output_map[2292] = &nf->fruitn_storage_to_fruitn_transfer;
		output_map[2293] = &nf->softstemn_storage_to_softstemn_transfer;
		output_map[2294] = &nf->livestemn_to_deadstemn;
		output_map[2295] = &nf->livestemn_to_retransn;
		output_map[2296] = &nf->livecrootn_to_deadcrootn;
		output_map[2297] = &nf->livecrootn_to_retransn;
		output_map[2298] = &nf->leafn_transfer_from_PLT;
		output_map[2299] = &nf->frootn_transfer_from_PLT;
		output_map[2300] = &nf->fruitn_transfer_from_PLT;
		output_map[2301] = &nf->softstemn_transfer_from_PLT;
		output_map[2302] = &nf->leafn_to_THN;
		output_map[2303] = &nf->leafn_storage_to_THN;
		output_map[2304] = &nf->leafn_transfer_to_THN;
		output_map[2305] = &nf->fruitn_to_THN;
		output_map[2306] = &nf->fruitn_storage_to_THN;
		output_map[2307] = &nf->fruitn_transfer_to_THN;
		output_map[2308] = &nf->livestemn_to_THN;
		output_map[2309] = &nf->livestemn_storage_to_THN;
		output_map[2310] = &nf->livestemn_transfer_to_THN;
		output_map[2311] = &nf->deadstemn_to_THN;
		output_map[2312] = &nf->deadstemn_storage_to_THN;
		output_map[2313] = &nf->deadstemn_transfer_to_THN;
		output_map[2314] = &nf->retransn_to_THN;
		output_map[2315] = &nf->THN_to_CTDBn_leaf;
		output_map[2316] = &nf->THN_to_CTDBn_fruit;
		output_map[2317] = &nf->THN_to_CTDBn_transfer;
		output_map[2318] = &nf->THN_to_CTDBn_cstem;
		output_map[2319] = &nf->STDBn_leaf_to_THN;
		output_map[2320] = &nf->STDBn_fruit_to_THN;
		output_map[2321] = &nf->STDBn_transfer_to_THN;
		output_map[2322] = &nf->leafn_to_MOW;
		output_map[2323] = &nf->leafn_storage_to_MOW;
		output_map[2324] = &nf->leafn_transfer_to_MOW;
		output_map[2325] = &nf->fruitn_to_MOW;
		output_map[2326] = &nf->fruitn_storage_to_MOW;
		output_map[2327] = &nf->fruitn_transfer_to_MOW;
		output_map[2328] = &nf->softstemn_to_MOW;
		output_map[2329] = &nf->softstemn_storage_to_MOW;
		output_map[2330] = &nf->softstemn_transfer_to_MOW;
		output_map[2331] = &nf->retransn_to_MOW;
		output_map[2332] = &nf->MOW_to_CTDBn_leaf;
		output_map[2333] = &nf->MOW_to_CTDBn_fruit;
		output_map[2334] = &nf->MOW_to_CTDBn_softstem;
		output_map[2335] = &nf->MOW_to_CTDBn_transfer;
		output_map[2336] = &nf->STDBn_leaf_to_MOW;
		output_map[2337] = &nf->STDBn_fruit_to_MOW;
		output_map[2338] = &nf->STDBn_softstem_to_MOW;
		output_map[2339] = &nf->STDBn_transfer_to_MOW;
		output_map[2340] = &nf->leafn_to_HRV;
		output_map[2341] = &nf->leafn_storage_to_HRV;
		output_map[2342] = &nf->leafn_transfer_to_HRV;
		output_map[2343] = &nf->fruitn_to_HRV;
		output_map[2344] = &nf->fruitn_storage_to_HRV;
		output_map[2345] = &nf->fruitn_transfer_to_HRV;
		output_map[2346] = &nf->softstemn_to_HRV;
		output_map[2347] = &nf->softstemn_storage_to_HRV;
		output_map[2348] = &nf->softstemn_transfer_to_HRV;
		output_map[2349] = &nf->retransn_to_HRV;
		output_map[2350] = &nf->HRV_to_CTDBn_leaf;
		output_map[2351] = &nf->HRV_to_CTDBn_fruit;
		output_map[2352] = &nf->HRV_to_CTDBn_softstem;
		output_map[2353] = &nf->HRV_to_CTDBn_transfer;
		output_map[2354] = &nf->STDBn_leaf_to_HRV;
		output_map[2355] = &nf->STDBn_fruit_to_HRV;
		output_map[2356] = &nf->STDBn_softstem_to_HRV;
		output_map[2357] = &nf->STDBn_transfer_to_HRV;
		output_map[2358] = &nf->leafn_to_PLG;
		output_map[2359] = &nf->leafn_storage_to_PLG;
		output_map[2360] = &nf->leafn_transfer_to_PLG;
		output_map[2361] = &nf->frootn_to_PLG;
		output_map[2362] = &nf->frootn_storage_to_PLG;
		output_map[2363] = &nf->frootn_transfer_to_PLG;
		output_map[2364] = &nf->fruitn_to_PLG;
		output_map[2365] = &nf->fruitn_storage_to_PLG;
		output_map[2366] = &nf->fruitn_transfer_to_PLG;
		output_map[2367] = &nf->softstemn_to_PLG;
		output_map[2368] = &nf->softstemn_storage_to_PLG;
		output_map[2369] = &nf->softstemn_transfer_to_PLG;
		output_map[2370] = &nf->retransn_to_PLG;
		output_map[2371] = &nf->STDBn_leaf_to_PLG;
		output_map[2372] = &nf->STDBn_froot_to_PLG;
		output_map[2373] = &nf->STDBn_fruit_to_PLG;
		output_map[2374] = &nf->STDBn_softstem_to_PLG;
		output_map[2375] = &nf->STDBn_transfer_to_PLG;
		output_map[2376] = &nf->CTDBn_leaf_to_PLG;
		output_map[2377] = &nf->CTDBn_fruit_to_PLG;
		output_map[2378] = &nf->CTDBn_softstem_to_PLG;
		output_map[2379] = &nf->leafn_to_GRZ;
		output_map[2380] = &nf->leafn_storage_to_GRZ;
		output_map[2381] = &nf->leafn_transfer_to_GRZ;
		output_map[2382] = &nf->fruitn_to_GRZ;
		output_map[2383] = &nf->fruitn_storage_to_GRZ;
		output_map[2384] = &nf->fruitn_transfer_to_GRZ;
		output_map[2385] = &nf->softstemn_to_GRZ;
		output_map[2386] = &nf->softstemn_storage_to_GRZ;
		output_map[2387] = &nf->softstemn_transfer_to_GRZ;
		output_map[2388] = &nf->STDBn_leaf_to_GRZ;
		output_map[2389] = &nf->STDBn_fruit_to_GRZ;
		output_map[2390] = &nf->STDBn_softstem_to_GRZ;
		output_map[2391] = &nf->STDBn_transfer_to_GRZ;
		output_map[2392] = &nf->retransn_to_GRZ;
		output_map[2393] = &nf->GRZ_to_litr1n;
		output_map[2394] = &nf->GRZ_to_litr2n;
		output_map[2395] = &nf->GRZ_to_litr3n;
		output_map[2396] = &nf->GRZ_to_litr4n;
		output_map[2397] = &nf->FRZ_to_sminNH4;
		output_map[2398] = &nf->FRZ_to_sminNO3;
		output_map[2399] = &nf->FRZ_to_litr1n;
		output_map[2400] = &nf->FRZ_to_litr2n;
		output_map[2401] = &nf->FRZ_to_litr3n;
		output_map[2402] = &nf->FRZ_to_litr4n;
		output_map[2403] = &nf->N2O_flux_GRZ;
		output_map[2404] = &nf->N2O_flux_FRZ;
		output_map[2500] = &epv->leafday;
		output_map[2501] = &epv->leafday_lastmort;
		output_map[2502] = &epv->n_actphen;
		output_map[2503] = &epv->thermal_timeSUM_max;
		output_map[2504] = &epv->flowHS_mort;
		output_map[2505] = &epv->transfer_ratio;
		output_map[2506] = &epv->day_leafc_litfall_increment;
		output_map[2507] = &epv->day_fruitc_litfall_increment;
		output_map[2508] = &epv->day_softstemc_litfall_increment;
		output_map[2509] = &epv->day_frootc_litfall_increment;
		output_map[2510] = &epv->day_livestemc_turnover_increment;
		output_map[2511] = &epv->day_livecrootc_turnover_increment;
		output_map[2512] = &epv->annmax_leafc;
		output_map[2513] = &epv->annmax_fruitc;
		output_map[2514] = &epv->annmax_softstemc;
		output_map[2515] = &epv->annmax_frootc;
		output_map[2516] = &epv->annmax_livestemc;
		output_map[2517] = &epv->annmax_livecrootc;
		output_map[2518] = &epv->dsr;
		output_map[2519] = &epv->dsws;
		output_map[2520] = &epv->proj_lai;
		output_map[2521] = &epv->all_lai;
		output_map[2522] = &epv->sla_avg;
		output_map[2523] = &epv->plaisun;
		output_map[2524] = &epv->plaishade;
		output_map[2525] = &epv->sun_proj_sla;
		output_map[2526] = &epv->shade_proj_sla;
		output_map[2527] = &epv->plant_height;
		output_map[2528] = &epv->NDVI;
		output_map[2529] = &epv->rootlength_prop[0];
		output_map[2530] = &epv->rootlength_prop[1];
		output_map[2531] = &epv->rootlength_prop[2];
		output_map[2532] = &epv->rootlength_prop[3];
		output_map[2533] = &epv->rootlength_prop[4];
		output_map[2534] = &epv->rootlength_prop[5];
		output_map[2535] = &epv->rootlength_prop[6];
		output_map[2536] = &epv->rootlength_prop[7];
		output_map[2537] = &epv->rootlength_prop[8];
		output_map[2538] = &epv->rootlength_prop[9];
		output_map[2539] = &epv->psi[0];
		output_map[2540] = &epv->psi[1];
		output_map[2541] = &epv->psi[2];
		output_map[2542] = &epv->psi[3];
		output_map[2543] = &epv->psi[4];
		output_map[2544] = &epv->psi[5];
		output_map[2545] = &epv->psi[6];
		output_map[2546] = &epv->psi[7];
		output_map[2547] = &epv->psi[8];
		output_map[2548] = &epv->psi[9];
		output_map[2549] = &epv->pF[0];
		output_map[2550] = &epv->pF[1];
		output_map[2551] = &epv->pF[2];
		output_map[2552] = &epv->pF[3];
		output_map[2553] = &epv->pF[4];
		output_map[2554] = &epv->pF[5];
		output_map[2555] = &epv->pF[6];
		output_map[2556] = &epv->pF[7];
		output_map[2557] = &epv->pF[8];
		output_map[2558] = &epv->pF[9];
		output_map[2559] = &epv->hydr_conduct_S[0];
		output_map[2560] = &epv->hydr_conduct_S[1];
		output_map[2561] = &epv->hydr_conduct_S[2];
		output_map[2562] = &epv->hydr_conduct_S[3];
		output_map[2563] = &epv->hydr_conduct_S[4];
		output_map[2564] = &epv->hydr_conduct_S[5];
		output_map[2565] = &epv->hydr_conduct_S[6];
		output_map[2566] = &epv->hydr_conduct_S[7];
		output_map[2567] = &epv->hydr_conduct_S[8];
		output_map[2568] = &epv->hydr_conduct_S[9];
		output_map[2569] = &epv->hydr_diffus_S[0];
		output_map[2570] = &epv->hydr_diffus_S[1];
		output_map[2571] = &epv->hydr_diffus_S[2];
		output_map[2572] = &epv->hydr_diffus_S[3];
		output_map[2573] = &epv->hydr_diffus_S[4];
		output_map[2574] = &epv->hydr_diffus_S[5];
		output_map[2575] = &epv->hydr_diffus_S[6];
		output_map[2576] = &epv->hydr_diffus_S[7];
		output_map[2577] = &epv->hydr_diffus_S[8];
		output_map[2578] = &epv->hydr_diffus_S[9];
		output_map[2579] = &epv->hydr_conduct_E[0];
		output_map[2580] = &epv->hydr_conduct_E[1];
		output_map[2581] = &epv->hydr_conduct_E[2];
		output_map[2582] = &epv->hydr_conduct_E[3];
		output_map[2583] = &epv->hydr_conduct_E[4];
		output_map[2584] = &epv->hydr_conduct_E[5];
		output_map[2585] = &epv->hydr_conduct_E[6];
		output_map[2586] = &epv->hydr_conduct_E[7];
		output_map[2587] = &epv->hydr_conduct_E[8];
		output_map[2588] = &epv->hydr_conduct_E[9];
		output_map[2589] = &epv->hydr_diffus_E[0];
		output_map[2590] = &epv->hydr_diffus_E[1];
		output_map[2591] = &epv->hydr_diffus_E[2];
		output_map[2592] = &epv->hydr_diffus_E[3];
		output_map[2593] = &epv->hydr_diffus_E[4];
		output_map[2594] = &epv->hydr_diffus_E[5];
		output_map[2595] = &epv->hydr_diffus_E[6];
		output_map[2596] = &epv->hydr_diffus_E[7];
		output_map[2597] = &epv->hydr_diffus_E[8];
		output_map[2598] = &epv->hydr_diffus_E[9];
		output_map[2599] = &epv->vwc[0];
		output_map[2600] = &epv->vwc[1];
		output_map[2601] = &epv->vwc[2];
		output_map[2602] = &epv->vwc[3];
		output_map[2603] = &epv->vwc[4];
		output_map[2604] = &epv->vwc[5];
		output_map[2605] = &epv->vwc[6];
		output_map[2606] = &epv->vwc[7];
		output_map[2607] = &epv->vwc[8];
		output_map[2608] = &epv->vwc[9];
		output_map[2609] = &epv->rooting_depth;
		output_map[2610] = &epv->psi_avg;
		output_map[2611] = &epv->vwc_avg;
		output_map[2612] = &epv->vwc_ratio_crit1[0];
		output_map[2613] = &epv->vwc_ratio_crit1[1];
		output_map[2614] = &epv->vwc_ratio_crit1[2];
		output_map[2615] = &epv->vwc_ratio_crit1[3];
		output_map[2616] = &epv->vwc_ratio_crit1[4];
		output_map[2617] = &epv->vwc_ratio_crit1[5];
		output_map[2618] = &epv->vwc_ratio_crit1[6];
		output_map[2619] = &epv->vwc_ratio_crit1[7];
		output_map[2620] = &epv->vwc_ratio_crit1[8];
		output_map[2621] = &epv->vwc_ratio_crit1[9];
		output_map[2622] = &epv->vwc_ratio_crit2[0];
		output_map[2623] = &epv->vwc_ratio_crit2[1];
		output_map[2624] = &epv->vwc_ratio_crit2[2];
		output_map[2625] = &epv->vwc_ratio_crit2[3];
		output_map[2626] = &epv->vwc_ratio_crit2[4];
		output_map[2627] = &epv->vwc_ratio_crit2[5];
		output_map[2628] = &epv->vwc_ratio_crit2[6];
		output_map[2629] = &epv->vwc_ratio_crit2[7];
		output_map[2630] = &epv->vwc_ratio_crit2[8];
		output_map[2631] = &epv->vwc_ratio_crit2[9];
		output_map[2632] = &epv->vwc_crit1[0];
		output_map[2633] = &epv->vwc_crit1[1];
		output_map[2634] = &epv->vwc_crit1[2];
		output_map[2635] = &epv->vwc_crit1[3];
		output_map[2636] = &epv->vwc_crit1[4];
		output_map[2637] = &epv->vwc_crit1[5];
		output_map[2638] = &epv->vwc_crit1[6];
		output_map[2639] = &epv->vwc_crit1[7];
		output_map[2640] = &epv->vwc_crit1[8];
		output_map[2641] = &epv->vwc_crit1[9];
		output_map[2642] = &epv->vwc_crit2[0];
		output_map[2643] = &epv->vwc_crit2[1];
		output_map[2644] = &epv->vwc_crit2[2];
		output_map[2645] = &epv->vwc_crit2[3];
		output_map[2646] = &epv->vwc_crit2[4];
		output_map[2647] = &epv->vwc_crit2[5];
		output_map[2648] = &epv->vwc_crit2[6];
		output_map[2649] = &epv->vwc_crit2[7];
		output_map[2650] = &epv->vwc_crit2[8];
		output_map[2651] = &epv->vwc_crit2[9];
		output_map[2652] = &epv->psi_crit1[0];
		output_map[2653] = &epv->psi_crit1[1];
		output_map[2654] = &epv->psi_crit1[2];
		output_map[2655] = &epv->psi_crit1[3];
		output_map[2656] = &epv->psi_crit1[4];
		output_map[2657] = &epv->psi_crit1[5];
		output_map[2658] = &epv->psi_crit1[6];
		output_map[2659] = &epv->psi_crit1[7];
		output_map[2660] = &epv->psi_crit1[8];
		output_map[2661] = &epv->psi_crit1[9];
		output_map[2662] = &epv->psi_crit2[0];
		output_map[2663] = &epv->psi_crit2[1];
		output_map[2664] = &epv->psi_crit2[2];
		output_map[2665] = &epv->psi_crit2[3];
		output_map[2666] = &epv->psi_crit2[4];
		output_map[2667] = &epv->psi_crit2[5];
		output_map[2668] = &epv->psi_crit2[6];
		output_map[2669] = &epv->psi_crit2[7];
		output_map[2670] = &epv->psi_crit2[8];
		output_map[2671] = &epv->psi_crit2[9];
		output_map[2672] = &epv->dlmr_area_sun;
		output_map[2673] = &epv->dlmr_area_shade;
		output_map[2674] = &epv->gl_t_wv_sun;
		output_map[2675] = &epv->gl_t_wv_shade;
		output_map[2676] = &epv->assim_sun;
		output_map[2677] = &epv->assim_shade;
		output_map[2678] = &epv->t_scalar[0];
		output_map[2679] = &epv->t_scalar[1];
		output_map[2680] = &epv->t_scalar[2];
		output_map[2681] = &epv->t_scalar[3];
		output_map[2682] = &epv->t_scalar[4];
		output_map[2683] = &epv->t_scalar[5];
		output_map[2684] = &epv->t_scalar[6];
		output_map[2685] = &epv->t_scalar[7];
		output_map[2686] = &epv->t_scalar[8];
		output_map[2687] = &epv->t_scalar[9];
		output_map[2688] = &epv->w_scalar[0];
		output_map[2689] = &epv->w_scalar[1];
		output_map[2690] = &epv->w_scalar[2];
		output_map[2691] = &epv->w_scalar[3];
		output_map[2692] = &epv->w_scalar[4];
		output_map[2693] = &epv->w_scalar[5];
		output_map[2694] = &epv->w_scalar[6];
		output_map[2695] = &epv->w_scalar[7];
		output_map[2696] = &epv->w_scalar[8];
		output_map[2697] = &epv->w_scalar[9];
		output_map[2698] = &epv->rate_scalar[0];
		output_map[2699] = &epv->rate_scalar[1];
		output_map[2700] = &epv->rate_scalar[2];
		output_map[2701] = &epv->rate_scalar[3];
		output_map[2702] = &epv->rate_scalar[4];
		output_map[2703] = &epv->rate_scalar[5];
		output_map[2704] = &epv->rate_scalar[6];
		output_map[2705] = &epv->rate_scalar[7];
		output_map[2706] = &epv->rate_scalar[8];
		output_map[2707] = &epv->rate_scalar[9];
		output_map[2708] = &epv->rate_scalar_avg;
		output_map[2709] = &epv->daily_gross_nmin[0];
		output_map[2710] = &epv->daily_gross_nmin[1];
		output_map[2711] = &epv->daily_gross_nmin[2];
		output_map[2712] = &epv->daily_gross_nmin[3];
		output_map[2713] = &epv->daily_gross_nmin[4];
		output_map[2714] = &epv->daily_gross_nmin[5];
		output_map[2715] = &epv->daily_gross_nmin[6];
		output_map[2716] = &epv->daily_gross_nmin[7];
		output_map[2717] = &epv->daily_gross_nmin[8];
		output_map[2718] = &epv->daily_gross_nmin[9];
		output_map[2719] = &epv->daily_gross_nimmob[0];
		output_map[2720] = &epv->daily_gross_nimmob[1];
		output_map[2721] = &epv->daily_gross_nimmob[2];
		output_map[2722] = &epv->daily_gross_nimmob[3];
		output_map[2723] = &epv->daily_gross_nimmob[4];
		output_map[2724] = &epv->daily_gross_nimmob[5];
		output_map[2725] = &epv->daily_gross_nimmob[6];
		output_map[2726] = &epv->daily_gross_nimmob[7];
		output_map[2727] = &epv->daily_gross_nimmob[8];
		output_map[2728] = &epv->daily_gross_nimmob[9];
		output_map[2729] = &epv->daily_net_nmin[0];
		output_map[2730] = &epv->daily_net_nmin[1];
		output_map[2731] = &epv->daily_net_nmin[2];
		output_map[2732] = &epv->daily_net_nmin[3];
		output_map[2733] = &epv->daily_net_nmin[4];
		output_map[2734] = &epv->daily_net_nmin[5];
		output_map[2735] = &epv->daily_net_nmin[6];
		output_map[2736] = &epv->daily_net_nmin[7];
		output_map[2737] = &epv->daily_net_nmin[8];
		output_map[2738] = &epv->daily_net_nmin[9];
		output_map[2739] = &epv->max_conduct;
		output_map[2740] = &epv->m_tmin;
		output_map[2741] = &epv->m_soilstress_layer[0];
		output_map[2742] = &epv->m_soilstress_layer[1];
		output_map[2743] = &epv->m_soilstress_layer[2];
		output_map[2744] = &epv->m_soilstress_layer[3];
		output_map[2745] = &epv->m_soilstress_layer[4];
		output_map[2746] = &epv->m_soilstress_layer[5];
		output_map[2747] = &epv->m_soilstress_layer[6];
		output_map[2748] = &epv->m_soilstress_layer[7];
		output_map[2749] = &epv->m_soilstress_layer[8];
		output_map[2750] = &epv->m_soilstress_layer[9];
		output_map[2751] = &epv->m_soilstress;
		output_map[2752] = &epv->m_ppfd_sun;
		output_map[2753] = &epv->m_ppfd_shade;
		output_map[2754] = &epv->m_vpd;
		output_map[2755] = &epv->m_final_sun;
		output_map[2756] = &epv->m_final_shade;
		output_map[2757] = &epv->gl_bl;
		output_map[2758] = &epv->gl_c;
		output_map[2759] = &epv->gl_s_sun;
		output_map[2760] = &epv->gl_s_shade;
		output_map[2761] = &epv->gl_e_wv;
		output_map[2762] = &epv->gl_sh;
		output_map[2763] = &epv->gc_e_wv;
		output_map[2764] = &epv->gc_sh;
		output_map[2765] = &epv->ytd_maxplai;
		output_map[2766] = &epv->n_limitation[0];
		output_map[2767] = &epv->n_limitation[1];
		output_map[2768] = &epv->n_limitation[2];
		output_map[2769] = &epv->n_limitation[3];
		output_map[2770] = &epv->n_limitation[4];
		output_map[2771] = &epv->n_limitation[5];
		output_map[2772] = &epv->n_limitation[6];
		output_map[2773] = &epv->n_limitation[7];
		output_map[2774] = &epv->n_limitation[8];
		output_map[2775] = &epv->n_limitation[9];
		output_map[2776] = &epv->plant_calloc;
		output_map[2777] = &epv->plant_nalloc;
		output_map[2778] = &epv->excess_c;
		output_map[2779] = &epv->pnow;
		output_map[2780] = &epv->NSC_limit_nw;
		output_map[2781] = &epv->NSC_limit_w;
		output_map[2782] = &epv->SMSI;
		output_map[2900] = &psn_sun->pa;
		output_map[2901] = &psn_shade->pa;
		output_map[2902] = &psn_sun->co2;
		output_map[2903] = &psn_shade->co2;
		output_map[2904] = &psn_sun->t;
		output_map[2905] = &psn_shade->t;
		output_map[2906] = &psn_sun->lnc;
		output_map[2907] = &psn_shade->lnc;
		output_map[2908] = &psn_sun->flnr;
		output_map[2909] = &psn_shade->flnr;
		output_map[2910] = &psn_sun->flnp;
		output_map[2911] = &psn_shade->flnp;
		output_map[2912] = &psn_sun->ppfd;
		output_map[2913] = &psn_shade->ppfd;
		output_map[2914] = &psn_sun->g;
		output_map[2915] = &psn_shade->g;
		output_map[2916] = &psn_sun->dlmr;
		output_map[2917] = &psn_shade->dlmr;
		output_map[2918] = &psn_sun->Ci;
		output_map[2919] = &psn_shade->Ci;
		output_map[2920] = &psn_sun->O2;
		output_map[2921] = &psn_shade->O2;
		output_map[2922] = &psn_sun->Ca;
		output_map[2923] = &psn_shade->Ca;
		output_map[2924] = &psn_sun->gamma;
		output_map[2925] = &psn_shade->gamma;
		output_map[2926] = &psn_sun->Kc;
		output_map[2927] = &psn_shade->Kc;
		output_map[2928] = &psn_sun->Ko;
		output_map[2929] = &psn_shade->Ko;
		output_map[2930] = &psn_sun->Vmax;
		output_map[2931] = &psn_shade->Vmax;
		output_map[2932] = &psn_sun->Jmax;
		output_map[2933] = &psn_shade->Jmax;
		output_map[2934] = &psn_sun->J;
		output_map[2935] = &psn_shade->J;
		output_map[2936] = &psn_sun->Av;
		output_map[2937] = &psn_shade->Av;
		output_map[2938] = &psn_sun->Aj;
		output_map[2939] = &psn_shade->Aj;
		output_map[2940] = &psn_sun->A;
		output_map[2941] = &psn_shade->A;
		output_map[3000] = &summary->annprcp;
		output_map[3001] = &summary->anntavg;
		output_map[3002] = &summary->annrunoff;
		output_map[3003] = &summary->annoutflow;
		output_map[3004] = &summary->daily_n2o;
		output_map[3005] = &summary->daily_nep;
		output_map[3006] = &summary->daily_npp;
		output_map[3007] = &summary->daily_nee;
		output_map[3008] = &summary->daily_nbp;
		output_map[3009] = &summary->daily_gpp;
		output_map[3010] = &summary->daily_mr;
		output_map[3011] = &summary->daily_gr;
		output_map[3012] = &summary->daily_hr;
		output_map[3013] = &summary->daily_sr;
		output_map[3014] = &summary->daily_tr;
		output_map[3015] = &summary->daily_fire;
		output_map[3016] = &summary->daily_litfallc;
		output_map[3017] = &summary->daily_litfallc_above;
		output_map[3018] = &summary->daily_litfallc_below;
		output_map[3019] = &summary->daily_litdecomp;
		output_map[3020] = &summary->daily_litfire;
		output_map[3021] = &summary->daily_litter;
		output_map[3022] = &summary->cum_npp;
		output_map[3023] = &summary->cum_nep;
		output_map[3024] = &summary->cum_nee;
		output_map[3025] = &summary->cum_gpp;
		output_map[3026] = &summary->cum_mr;
		output_map[3027] = &summary->cum_gr;
		output_map[3028] = &summary->cum_hr;
		output_map[3029] = &summary->cum_fire;
		output_map[3030] = &summary->cum_n2o;
		output_map[3031] = &summary->cum_Closs_MGM;
		output_map[3032] = &summary->cum_Cplus_MGM;
		output_map[3033] = &summary->cum_Closs_THN_w;
		output_map[3034] = &summary->cum_Closs_THN_nw;
		output_map[3035] = &summary->cum_Closs_MOW;
		output_map[3036] = &summary->cum_Closs_HRV;
		output_map[3037] = &summary->cum_yieldC_HRV;
		output_map[3038] = &summary->cum_Closs_PLG;
		output_map[3039] = &summary->cum_Closs_GRZ;
		output_map[3040] = &summary->cum_Cplus_GRZ;
		output_map[3041] = &summary->cum_Cplus_FRZ;
		output_map[3042] = &summary->cum_Cplus_PLT;
		output_map[3043] = &summary->cum_Nplus_GRZ;
		output_map[3044] = &summary->cum_Nplus_FRZ;
		output_map[3045] = &summary->cum_Closs_SNSC;
		output_map[3046] = &summary->cum_Cplus_STDB;
		output_map[3047] = &summary->cum_Cplus_CTDB;
		output_map[3048] = &summary->cum_ET;
		output_map[3049] = &summary->vegc;
		output_map[3050] = &summary->abgc;
		output_map[3051] = &summary->litrc;
		output_map[3052] = &summary->soilc;
		output_map[3053] = &summary->soiln;
		output_map[3054] = &summary->sminn;
		output_map[3055] = &summary->totalc;
		output_map[3056] = &summary->humusC_top10;
		output_map[3057] = &summary->SOM_C_top10;
		output_map[3058] = &summary->SOM_N_top10;
		output_map[3059] = &summary->NH4_top10;
		output_map[3060] = &summary->NO3_top10;
		output_map[3061] = &summary->daily_gross_nmin_total;
		output_map[3062] = &summary->daily_gross_nimmob_total;
		output_map[3063] = &summary->daily_net_nmin_total;


	}
	
	return (!ok);
}
		
